@@ -18,7 +18,9 @@
 #ifndef MYSQL_XDEVAPI_MYSQLND_API_H
 #define MYSQL_XDEVAPI_MYSQLND_API_H
 
+#ifdef __cplusplus
 extern "C" {
+#endif
 
 #ifdef PHP_WIN32
 #pragma warning( push )
@@ -108,15 +110,8 @@ extern "C" {
 
 #endif // PHP_WIN32
 
+#ifdef __cplusplus
 } // extern "C"
+#endif
 
 #endif // MYSQL_XDEVAPI_MYSQLND_API_H
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
