@@ -13,14 +13,13 @@
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Andrey Hristov <andrey@php.net>                             |
+  |          Filip Janiszewski <fjanisze@php.net>                        |
+  |          Darek Slusarczyk <marines@php.net>                          |
   +----------------------------------------------------------------------+
 */
 #include "php_api.h"
 #include "mysqlnd_api.h"
-extern "C" {
-#include <ext/json/php_json.h>
-#include <ext/json/php_json_parser.h>
-}
+#include "json_api.h"
 #include "xmysqlnd/xmysqlnd.h"
 #include "xmysqlnd/xmysqlnd_session.h"
 #include "xmysqlnd/xmysqlnd_schema.h"
@@ -61,39 +60,23 @@ ZEND_END_ARG_INFO()
 
 //------------------------------------------------------------------------------
 
-
-/* {{{ execute_statement */
 enum_func_status
-execute_statement(xmysqlnd_stmt* stmt,zval* return_value)
+execute_statement(xmysqlnd_stmt& stmt, zval* resultset)
 {
-	enum_func_status ret{FAIL};
-	if (stmt) {
-		zval stmt_zv;
-		ZVAL_UNDEF(&stmt_zv);
-		mysqlx_new_stmt(&stmt_zv, stmt);
-		if (Z_TYPE(stmt_zv) == IS_NULL) {
-			xmysqlnd_stmt_free(stmt, nullptr, nullptr);
-		}
-		if (Z_TYPE(stmt_zv) == IS_OBJECT) {
-			zval zv;
-			ZVAL_UNDEF(&zv);
-			zend_long flags{0};
-			mysqlx_statement_execute_read_response(Z_MYSQLX_P(&stmt_zv),
-								flags, MYSQLX_RESULT, &zv);
-			ZVAL_COPY(return_value, &zv);
-			zval_dtor(&zv);
-			ret = PASS;
-		}
-		zval_ptr_dtor(&stmt_zv);
+	util::zvalue stmt_zv;
+	mysqlx_new_stmt(stmt_zv.ptr(), &stmt);
+	if (stmt_zv.is_null()) {
+		xmysqlnd_stmt_free(&stmt, nullptr, nullptr);
+		return FAIL;
 	}
-	return ret;
+	if (!stmt_zv.is_object()) {
+		return FAIL;
+	}
+	zend_long flags{0};
+	mysqlx_statement_execute_read_response(Z_MYSQLX_P(stmt_zv.ptr()),
+						flags, MYSQLX_RESULT, resultset);
+	return PASS;
 }
-/* }}} */
-
-
-#define ID_COLUMN_NAME		"_id"
-#define ID_TEMPLATE_PREFIX	"\"" ID_COLUMN_NAME "\":\""
-#define ID_TEMPLATE_SUFFIX	"\"}"
 
 enum class Add_op_status
 {
@@ -108,139 +91,98 @@ struct doc_add_op_return_status
 	MYSQLND_CSTRING doc_id;
 };
 
-/* {{{ collection_add_string */
 Add_op_status
 collection_add_string(
 	st_xmysqlnd_crud_collection_op__add* add_op,
-	zval* doc,
-	zval* /*return_value*/)
+	util::zvalue& doc)
 {
-	if( PASS == xmysqlnd_crud_collection_add__add_doc(add_op,doc) ) {
+	if( PASS == xmysqlnd_crud_collection_add__add_doc(add_op, doc.ptr()) ) {
 		return Add_op_status::success;
 	}
 	return Add_op_status::fail;
 }
-/* }}} */
 
-
-/* {{{ collection_add_object*/
-Add_op_status
-collection_add_object_impl(
-	st_xmysqlnd_crud_collection_op__add* add_op,
-	zval* doc,
-	zval* /*return_value*/)
-{
-	zval new_doc;
-	Add_op_status ret = Add_op_status::fail;
-	util::json::to_zv_string(doc, &new_doc);
-	if( PASS == xmysqlnd_crud_collection_add__add_doc(add_op, &new_doc) ) {
-		ret = Add_op_status::success;
-	}
-	zval_dtor(&new_doc);
-	return ret;
-}
-/* }}} */
-
-
-/* {{{ collection_add_object*/
 Add_op_status
 collection_add_object(
 	st_xmysqlnd_crud_collection_op__add* add_op,
-	zval* doc,
-	zval* return_value)
-{
-	return collection_add_object_impl(
-				add_op, doc, return_value);
-}
-/* }}} */
-
-
-/* {{{ collection_add_array*/
-Add_op_status
-collection_add_array(
-	st_xmysqlnd_crud_collection_op__add* add_op,
-	zval* doc,
-	zval* return_value)
+	util::zvalue& doc)
 {
 	Add_op_status ret = Add_op_status::fail;
-	if( zend_hash_num_elements(Z_ARRVAL_P(doc)) == 0 ) {
+	util::zvalue new_doc(util::json::to_zv_string(doc));
+	if( PASS == xmysqlnd_crud_collection_add__add_doc(add_op, new_doc.ptr()) ) {
+		ret = Add_op_status::success;
+	}
+	return ret;
+}
+
+Add_op_status
+collection_add_array(
+	st_xmysqlnd_crud_collection_op__add* add_op,
+	util::zvalue& doc)
+{
+	Add_op_status ret = Add_op_status::fail;
+	if( doc.empty() ) {
 		ret = Add_op_status::noop;
 	} else {
-		ret = collection_add_object_impl(
-			add_op, doc, return_value);
+		ret = collection_add_object(add_op, doc);
 	}
 	return ret;
 }
-/* }}} */
 
 } // anonymous namespace
 
 //------------------------------------------------------------------------------
 
 
-/* {{{ Collection_add::init() */
 bool Collection_add::add_docs(
-	zval* obj_zv,
 	xmysqlnd_collection* coll,
 	zval* documents,
 	int num_of_documents)
 {
-	if (!obj_zv || !documents || !num_of_documents) return false;
+	if (!documents || !num_of_documents) return false;
 
 	for (int i{0}; i < num_of_documents; ++i) {
-		if (Z_TYPE(documents[i]) != IS_STRING &&
-			Z_TYPE(documents[i]) != IS_OBJECT &&
-			Z_TYPE(documents[i]) != IS_ARRAY) {
-			php_error_docref(nullptr, E_WARNING, "Only strings, objects and arrays can be added. Type is %u", Z_TYPE(documents[i]));
+		auto doc_type{ Z_TYPE(documents[i]) };
+		if (doc_type != IS_STRING &&
+			doc_type != IS_OBJECT &&
+			doc_type != IS_ARRAY) {
+			php_error_docref(
+				nullptr,
+				E_WARNING,
+				"Only strings, objects and arrays can be added. Type is %u",
+				doc_type);
 			return false;
 		}
 	}
 
 	if( !add_op ) {
 		if( !coll ) return false;
-		object_zv = obj_zv;
 		collection = coll->get_reference();
 		add_op = xmysqlnd_crud_collection_add__create(
 			mnd_str2c(collection->get_schema()->get_name()),
 			mnd_str2c(collection->get_name()));
 		if (!add_op) return false;
-	} else {
-		ZVAL_COPY(obj_zv, object_zv);
 	}
 
-	zval doc;
 	for (int i{0}; i < num_of_documents; ++i) {
-		ZVAL_DUP(&doc, &documents[i]);
-		docs.push_back( doc );
+		docs.push_back(util::zvalue::clone_from(&documents[i]));
 	}
 
 	return true;
 }
-/* }}} */
 
-
-/* {{{ Collection_add::init() */
 bool Collection_add::add_docs(
-	zval* obj_zv,
 	xmysqlnd_collection* coll,
 	const util::string_view& /*doc_id*/,
 	zval* doc)
 {
 	const int num_of_documents = 1;
-	if (!add_docs(obj_zv, coll, doc, num_of_documents)) return false;
+	if (!add_docs(coll, doc, num_of_documents)) return false;
 	return xmysqlnd_crud_collection_add__set_upsert(add_op) == PASS;
 }
-/* }}} */
 
-
-/* {{{ Collection_add::~Collection_add() */
 Collection_add::~Collection_add()
 {
-	for (size_t i{0}; i < docs.size(); ++i) {
-		zval_ptr_dtor(&docs[i]);
-		ZVAL_UNDEF(&docs[i]);
-	}
-
 	if (add_op) {
 		xmysqlnd_crud_collection_add__destroy(add_op);
 	}
@@ -249,45 +191,40 @@ Collection_add::~Collection_add()
 		xmysqlnd_collection_free(collection, nullptr, nullptr);
 	}
 }
-/* }}} */
 
-
-/* {{{ Collection_add::execute() */
-void Collection_add::execute(zval* return_value)
+void Collection_add::execute(zval* resultset)
 {
-	enum_func_status execute_ret_status{PASS};
-	size_t noop_cnt{0};
-
 	DBG_ENTER("Collection_add::execute");
 
-	RETVAL_FALSE;
-
+	size_t noop_cnt{0};
 	Add_op_status ret = Add_op_status::success;
-	for (size_t i{0}; i < docs.size() && ret != Add_op_status::fail ; ++i) {
+	for (auto it{docs.begin()}; it != docs.end() && ret != Add_op_status::fail ; ++it) {
 		ret = Add_op_status::fail;
-		switch(Z_TYPE(docs[i])) {
-		case IS_STRING:
-			ret = collection_add_string(
-				add_op, &docs[i], return_value);
+		util::zvalue doc(*it);
+		switch(doc.type()) {
+		case util::zvalue::Type::String:
+			ret = collection_add_string(add_op, doc);
 			break;
-		case IS_ARRAY:
-			ret = collection_add_array(
-				add_op, &docs[i], return_value);
+		case util::zvalue::Type::Array:
+			ret = collection_add_array(add_op, doc);
 			break;
-		case IS_OBJECT:
-			ret = collection_add_object(
-				add_op, &docs[i], return_value);
+		case util::zvalue::Type::Object:
+			ret = collection_add_object(add_op, doc);
 			break;
+		default:
+			assert(!"should not happen!");
+			ret = Add_op_status::fail;
 		}
 		if( ret == Add_op_status::noop ) {
 			++noop_cnt;
 		}
 	}
 
-	if ( execute_ret_status != FAIL && docs.size() > noop_cnt ) {
+	enum_func_status execute_ret_status{PASS};
+	if ( docs.size() > noop_cnt ) {
 		xmysqlnd_stmt* stmt = collection->add(add_op);
 		if( nullptr != stmt ) {
-			execute_ret_status =  execute_statement(stmt,return_value);
+			execute_ret_status = execute_statement(*stmt, resultset);
 		} else {
 			execute_ret_status = FAIL;
 		}
@@ -297,27 +234,20 @@ void Collection_add::execute(zval* return_value)
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
-
 
 //------------------------------------------------------------------------------
 
 
-/* {{{ mysqlx_collection__add::__construct */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__add, __construct)
 {
 	UNUSED_INTERNAL_FUNCTION_PARAMETERS();
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__add::execute() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__add, execute)
 {
-	zval* object_zv{nullptr};
-
 	DBG_ENTER("mysqlx_collection__add::execute");
 
+	zval* object_zv{nullptr};
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "O",
 												&object_zv,
 												collection_add_class_entry))
@@ -330,10 +260,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__add, execute)
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__add::add() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__add, add)
 {
 	zval* object_zv{nullptr};
@@ -355,14 +282,13 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__add, add)
 	 * For subsequent calls to add_docs, the xmysqlnd_collection is set to NULL
 	 */
 	Collection_add& coll_add = util::fetch_data_object<Collection_add>(object_zv);
-	coll_add.add_docs(return_value, nullptr, docs, num_of_docs);
+	if (coll_add.add_docs(nullptr, docs, num_of_docs)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ mysqlx_collection__add_methods[] */
 static const zend_function_entry mysqlx_collection__add_methods[] = {
 	PHP_ME(mysqlx_collection__add, __construct,	nullptr,											ZEND_ACC_PRIVATE)
 
@@ -371,10 +297,8 @@ static const zend_function_entry mysqlx_collection__add_methods[] = {
 
 	{nullptr, nullptr, nullptr}
 };
-/* }}} */
 
 #if 0
-/* {{{ mysqlx_collection__add_property__name */
 static zval *
 mysqlx_collection__add_property__name(const st_mysqlx_object* obj, zval* return_value)
 {
@@ -394,7 +318,7 @@ mysqlx_collection__add_property__name(const st_mysqlx_object* obj, zval* return_
 	}
 	DBG_RETURN(return_value);
 }
-/* }}} */
+
 #endif
 
 static zend_object_handlers collection_add_handlers;
@@ -408,16 +332,12 @@ const st_mysqlx_property_entry collection_add_property_entries[] =
 	{{nullptr,	0}, nullptr, nullptr}
 };
 
-/* {{{ mysqlx_collection__add_free_storage */
 static void
 mysqlx_collection__add_free_storage(zend_object* object)
 {
 	util::free_object<Collection_add>(object);
 }
-/* }}} */
 
-
-/* {{{ php_mysqlx_collection__add_object_allocator */
 static zend_object *
 php_mysqlx_collection__add_object_allocator(zend_class_entry* class_type)
 {
@@ -428,10 +348,7 @@ php_mysqlx_collection__add_object_allocator(zend_class_entry* class_type)
 		&collection_add_properties);
 	DBG_RETURN(&mysqlx_object->zo);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_register_collection__add_class */
 void
 mysqlx_register_collection__add_class(UNUSED_INIT_FUNC_ARGS, zend_object_handlers* mysqlx_std_object_handlers)
 {
@@ -452,19 +369,13 @@ mysqlx_register_collection__add_class(UNUSED_INIT_FUNC_ARGS, zend_object_handler
 	zend_declare_property_null(collection_add_class_entry, "name",	sizeof("name") - 1,	ZEND_ACC_PUBLIC);
 #endif
 }
-/* }}} */
 
-
-/* {{{ mysqlx_unregister_collection__add_class */
 void
 mysqlx_unregister_collection__add_class(UNUSED_SHUTDOWN_FUNC_ARGS)
 {
 	zend_hash_destroy(&collection_add_properties);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_new_collection__add */
 void
 mysqlx_new_collection__add(
 	zval* return_value,
@@ -477,7 +388,7 @@ mysqlx_new_collection__add(
 	if (SUCCESS == object_init_ex(return_value, collection_add_class_entry) && IS_OBJECT == Z_TYPE_P(return_value)) {
 		const st_mysqlx_object* const mysqlx_object = Z_MYSQLX_P(return_value);
 		Collection_add* const coll_add = static_cast<Collection_add*>(mysqlx_object->ptr);
-		if (!coll_add || !coll_add->add_docs(return_value, collection, docs, num_of_docs)) {
+		if (!coll_add || !coll_add->add_docs(collection, docs, num_of_docs)) {
 			php_error_docref(nullptr, E_WARNING, "invalid object of class %s", ZSTR_VAL(mysqlx_object->zo.ce->name));
 			zval_ptr_dtor(return_value);
 			ZVAL_NULL(return_value);
@@ -486,17 +397,7 @@ mysqlx_new_collection__add(
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
 } // namespace devapi
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
