@@ -13,11 +13,15 @@
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Andrey Hristov <andrey@php.net>                             |
+  |          Filip Janiszewski <fjanisze@php.net>                        |
+  |          Darek Slusarczyk <marines@php.net>                          |
   +----------------------------------------------------------------------+
 */
 #ifndef MYSQLX_COLLECTION__ADD_H
 #define MYSQLX_COLLECTION__ADD_H
 
+#include "util/value.h"
+
 namespace mysqlx {
 
 namespace drv {
@@ -29,37 +33,31 @@ struct st_xmysqlnd_crud_collection_op__add;
 
 namespace devapi {
 
-/* {{{ Collection_add */
 class Collection_add : public util::custom_allocable
 {
 public:
 	Collection_add() = default;
-	Collection_add(const Collection_add& rhs) = delete;
-	Collection_add& operator=(const Collection_add& rhs) = delete;
+	Collection_add(const Collection_add&) = delete;
+	Collection_add& operator=(const Collection_add&) = delete;
 	~Collection_add();
 
 	bool add_docs(
-		zval* object_zv,
 		drv::xmysqlnd_collection* collection,
 		zval* docs,
 		int num_of_docs);
 	bool add_docs(
-		zval* object_zv,
 		drv::xmysqlnd_collection* collection,
 		const util::string_view& single_doc_id,
 		zval* doc);
 
 public:
-	void execute(zval* return_value);
+	void execute(zval* resultset);
 
 private:
-	zval* object_zv{nullptr};
 	drv::xmysqlnd_collection* collection{nullptr};
 	drv::st_xmysqlnd_crud_collection_op__add* add_op{nullptr};
-	std::vector<zval> docs;
+	std::vector<util::zvalue> docs;
 };
-/* }}} */
-
 
 void mysqlx_new_collection__add(
 	zval* return_value,
@@ -74,12 +72,3 @@ void mysqlx_unregister_collection__add_class(SHUTDOWN_FUNC_ARGS);
 } // namespace mysqlx
 
 #endif /* MYSQLX_COLLECTION__ADD_H */
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
