@@ -13,6 +13,8 @@
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Andrey Hristov <andrey@php.net>                             |
+  |          Filip Janiszewski <fjanisze@php.net>                        |
+  |          Darek Slusarczyk <marines@php.net>                          |
   +----------------------------------------------------------------------+
 */
 #include "php_api.h"
@@ -38,6 +40,7 @@
 #include "mysqlx_exception.h"
 #include "util/allocator.h"
 #include "util/object.h"
+#include "util/value.h"
 #include "util/zend_utils.h"
 #include "xmysqlnd/xmysqlnd_utils.h"
 #include "xmysqlnd/crud_parsers/mysqlx_crud_parser.h"
@@ -55,15 +58,15 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_collection__find__fields, 0, ZEND_RETURN_V
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_collection__find__group_by, 0, ZEND_RETURN_VALUE, 1)
-	ZEND_ARG_INFO(no_pass_by_ref, sort_expr)
+	ZEND_ARG_INFO(no_pass_by_ref, sort_expressions)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_collection__find__having, 0, ZEND_RETURN_VALUE, 1)
-	ZEND_ARG_INFO(no_pass_by_ref, sort_expr)
+	ZEND_ARG_INFO(no_pass_by_ref, search_condition)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_collection__find__sort, 0, ZEND_RETURN_VALUE, 1)
-	ZEND_ARG_INFO(no_pass_by_ref, sort_expr)
+	ZEND_ARG_INFO(no_pass_by_ref, sort_expressions)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_collection__find__limit, 0, ZEND_RETURN_VALUE, 1)
@@ -94,15 +97,12 @@ ZEND_END_ARG_INFO()
 //------------------------------------------------------------------------------
 
 
-/* {{{ Collection_find::init() */
 bool Collection_find::init(
-	zval* obj_zv,
 	xmysqlnd_collection* coll,
 	const util::string_view& search_expression)
 {
-	if (!obj_zv || !coll) return false;
+	if (!coll) return false;
 
-	object_zv = obj_zv;
 	collection = coll->get_reference();
 	find_op = xmysqlnd_crud_collection_find__create(
 		mnd_str2c(collection->get_schema()->get_name()),
@@ -115,10 +115,7 @@ bool Collection_find::init(
 	return xmysqlnd_crud_collection_find__set_criteria(
 		find_op, search_expression.to_nd_cstr()) == PASS;
 }
-/* }}} */
 
-
-/* {{{ Collection_find::~Collection_find() */
 Collection_find::~Collection_find()
 {
 	if (find_op) {
@@ -129,118 +126,111 @@ Collection_find::~Collection_find()
 		xmysqlnd_collection_free(collection, nullptr, nullptr);
 	}
 }
-/* }}} */
 
-
-/* {{{ mysqlx_collection__find::fields */
-void Collection_find::fields(
-	const zval* fields,
-	zval* return_value)
+bool Collection_find::fields(util::zvalue& fields)
 {
 	DBG_ENTER("Collection_find::fields");
 
 	bool is_expression{false};
-	switch (Z_TYPE_P(fields)) {
-		case IS_STRING:
-		case IS_ARRAY:
+	switch (fields.type()) {
+		case util::zvalue::Type::String:
+		case util::zvalue::Type::Array:
 			break;
-		case IS_OBJECT:
-			if (is_a_mysqlx_expression(fields)) {
+		case util::zvalue::Type::Object:
+			if (is_a_mysqlx_expression(fields.ptr())) {
 				/* get the string */
-				fields = get_mysqlx_expression(fields);
+				fields = get_mysqlx_expression(fields.ptr());
 				is_expression = true;
 			}
 			break;
 		default:
 			RAISE_EXCEPTION(err_msg_invalid_type);
-			DBG_VOID_RETURN;
+			DBG_RETURN(false);
 	}
 
-	RETVAL_FALSE;
-
 	enum_func_status ret{PASS};
-	if (Z_TYPE_P(fields) == IS_STRING) {
-		const MYSQLND_CSTRING field_str = { Z_STRVAL_P(fields), Z_STRLEN_P(fields) };
+	if (fields.is_string()) {
+		const MYSQLND_CSTRING field_str{ fields.c_str(), fields.length() };
 		ret = xmysqlnd_crud_collection_find__set_fields(find_op, field_str, is_expression, TRUE);
-	} else if (Z_TYPE_P(fields) == IS_ARRAY) {
-		const zval* entry{nullptr};
-		MYSQLX_HASH_FOREACH_VAL(Z_ARRVAL_P(fields), entry) {
+	} else if (fields.is_array()) {
+		for (auto it{ fields.vbegin() }; it != fields.vend(); ++it) {
+			util::zvalue field(*it);
 			is_expression = false;
-			if (Z_TYPE_P(entry) == IS_OBJECT) {
-				if (is_a_mysqlx_expression(entry)) {
+			if (field.is_object()) {
+				if (is_a_mysqlx_expression(field.ptr())) {
 					/* get the string */
-					entry = get_mysqlx_expression(entry);
+					field = get_mysqlx_expression(field.ptr());
 					is_expression = true;
 				}
 			}
 			/* NO else */
-			if (Z_TYPE_P(entry) != IS_STRING) {
+			if (!field.is_string()) {
 				RAISE_EXCEPTION(err_msg_wrong_param_1);
-				DBG_VOID_RETURN;
+				DBG_RETURN(false);
 			}
-			MYSQLND_CSTRING field_str = { Z_STRVAL_P(entry), Z_STRLEN_P(entry) };
+			MYSQLND_CSTRING field_str{ field.c_str(), field.length() };
 			ret = xmysqlnd_crud_collection_find__set_fields(find_op, field_str, is_expression, TRUE);
 			if(ret==FAIL)
 				break;
-		} ZEND_HASH_FOREACH_END();
+		}
 	}
 	if (FAIL == ret) {
 		RAISE_EXCEPTION(err_msg_add_field);
+		DBG_RETURN(false);
 	}
-	ZVAL_COPY(return_value, object_zv);
 
-	DBG_VOID_RETURN;
+	DBG_RETURN(true);
 }
-/* }}} */
 
-
-/* {{{ Collection_find::add_operation */
-void Collection_find::add_operation(
+bool Collection_find::add_operation(
 	Collection_find::Operation operation,
-	zval* sort_expr,
-	int num_of_expr,
-	zval* return_value)
+	zval* sort_expressions,
+	int num_of_expr)
 {
 	DBG_ENTER("Collection_find::add_operation");
 
 	for( int i{0}; i < num_of_expr ; ++i ) {
-		if (Z_TYPE(sort_expr[i]) != IS_STRING &&
-			Z_TYPE(sort_expr[i]) != IS_OBJECT &&
-			Z_TYPE(sort_expr[i]) != IS_ARRAY) {
-			php_error_docref(nullptr, E_WARNING, "Only strings, objects and arrays can be added. Type is %u",
-							 Z_TYPE(sort_expr[i]));
-			DBG_VOID_RETURN;
+		auto sort_expr_type{ Z_TYPE(sort_expressions[i]) };
+		if (sort_expr_type != IS_STRING &&
+			sort_expr_type != IS_OBJECT &&
+			sort_expr_type != IS_ARRAY) {
+			php_error_docref(
+				nullptr,
+				E_WARNING,
+				"Only strings, objects and arrays can be added. Type is %u",
+				sort_expr_type);
+			DBG_RETURN(false);
 		}
 	}
 
-	RETVAL_FALSE;
-
 	for( int i{0}; i < num_of_expr ; ++i ) {
-		switch (Z_TYPE(sort_expr[i])) {
-		case IS_STRING:
+		const util::zvalue sort_expr(sort_expressions[i]);
+		switch (sort_expr.type()) {
+		case util::zvalue::Type::String:
 			{
-				const MYSQLND_CSTRING sort_expr_str = { Z_STRVAL(sort_expr[i]), Z_STRLEN(sort_expr[i]) };
+				const MYSQLND_CSTRING sort_expr_str{ sort_expr.c_str(), sort_expr.length() };
 				if (Collection_find::Operation::Sort == operation) {
-					if (PASS == xmysqlnd_crud_collection_find__add_sort(find_op, sort_expr_str)) {
-						ZVAL_COPY(return_value, object_zv);
+					if (FAIL == xmysqlnd_crud_collection_find__add_sort(find_op, sort_expr_str)) {
+						DBG_RETURN(false);
 					}
 				} else if (Collection_find::Operation::Group_by == operation) {
-					if (PASS == xmysqlnd_crud_collection_find__add_grouping(find_op, sort_expr_str)) {
-						ZVAL_COPY(return_value, object_zv);
+					if (FAIL == xmysqlnd_crud_collection_find__add_grouping(find_op, sort_expr_str)) {
+						DBG_RETURN(false);
 					}
 				}
 			}
 			break;
-		case IS_ARRAY:
+		case util::zvalue::Type::Array:
 			{
-				zval* entry{nullptr};
-				MYSQLX_HASH_FOREACH_VAL(Z_ARRVAL(sort_expr[i]), entry) {
-					enum_func_status ret{FAIL};
-					const MYSQLND_CSTRING sort_expr_str = { Z_STRVAL_P(entry), Z_STRLEN_P(entry) };
-					if (Z_TYPE_P(entry) != IS_STRING) {
+				for (auto it{ sort_expr.vbegin() }; it != sort_expr.vend(); ++it) {
+					const util::zvalue& sort_expr_entry(*it);
+					if (!sort_expr_entry.is_string()) {
 						RAISE_EXCEPTION(err_msg_wrong_param_1);
-						DBG_VOID_RETURN;
+						DBG_RETURN(false);
 					}
+					const MYSQLND_CSTRING sort_expr_str{
+						sort_expr_entry.c_str(), sort_expr_entry.length() };
+					enum_func_status ret{FAIL};
 					if (Collection_find::Operation::Sort == operation) {
 						ret = xmysqlnd_crud_collection_find__add_sort(find_op, sort_expr_str);
 					} else if (Collection_find::Operation::Group_by == operation) {
@@ -248,219 +238,128 @@ void Collection_find::add_operation(
 					}
 					if (FAIL == ret) {
 						RAISE_EXCEPTION(err_msg_add_sort_fail);
-						DBG_VOID_RETURN;
+						DBG_RETURN(false);
 					}
-				} ZEND_HASH_FOREACH_END();
-				ZVAL_COPY(return_value, object_zv);
+				}
 			}
 			break;
 		default:
 			RAISE_EXCEPTION(err_msg_wrong_param_3);
-			break;
+			DBG_RETURN(false);
 		}
 	}
-	DBG_VOID_RETURN;
+	DBG_RETURN(true);
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::sort() */
-void Collection_find::sort(
-	zval* sort_expr,
-	int num_of_expr,
-	zval* return_value)
+bool Collection_find::sort(
+	zval* sort_expressions,
+	int num_of_expr)
 {
 	DBG_ENTER("mysqlx_collection__find::sort");
-	add_operation(Operation::Sort, sort_expr, num_of_expr, return_value);
-	DBG_VOID_RETURN;
+	DBG_RETURN(add_operation(Operation::Sort, sort_expressions, num_of_expr));
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::group_by() */
-void Collection_find::group_by(
-	zval* sort_expr,
-	int num_of_expr,
-	zval* return_value)
+bool Collection_find::group_by(
+	zval* sort_expressions,
+	int num_of_expr)
 {
 	DBG_ENTER("mysqlx_collection__find::group_by");
-	add_operation(Operation::Group_by, sort_expr, num_of_expr, return_value);
-	DBG_VOID_RETURN;
+	DBG_RETURN(add_operation(Operation::Group_by, sort_expressions, num_of_expr));
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::having() */
-void Collection_find::having(
-	const MYSQLND_CSTRING& search_condition,
-	zval* return_value)
+bool Collection_find::having(const util::string_view& search_condition)
 {
 	DBG_ENTER("mysqlx_collection__find::having");
-
-	RETVAL_FALSE;
-
-	if (PASS == xmysqlnd_crud_collection_find__set_having(find_op, search_condition)) {
-		ZVAL_COPY(return_value, object_zv);
-	}
-
-	DBG_VOID_RETURN;
+	const MYSQLND_CSTRING search_condition_str{ search_condition.c_str(), search_condition.length() };
+	DBG_RETURN(PASS == xmysqlnd_crud_collection_find__set_having(find_op, search_condition_str));
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::limit() */
-void Collection_find::limit(
-	zend_long rows,
-	zval* return_value)
+bool Collection_find::limit(zend_long rows)
 {
 	DBG_ENTER("mysqlx_collection__find::limit");
 
 	if (rows < 0) {
 		RAISE_EXCEPTION(err_msg_wrong_param_2);
-		DBG_VOID_RETURN;
+		DBG_RETURN(false);
 	}
 
-	RETVAL_FALSE;
-
-	if (PASS == xmysqlnd_crud_collection_find__set_limit(find_op, rows)) {
-		ZVAL_COPY(return_value, object_zv);
-	}
-
-	DBG_VOID_RETURN;
+	DBG_RETURN(PASS == xmysqlnd_crud_collection_find__set_limit(find_op, rows));
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::offset() */
-void Collection_find::offset(
-	zend_long position,
-	zval* return_value)
+bool Collection_find::offset(zend_long position)
 {
 	DBG_ENTER("mysqlx_collection__find::offset");
 
 	if (position < 0) {
 		RAISE_EXCEPTION(err_msg_wrong_param_2);
-		DBG_VOID_RETURN;
+		DBG_RETURN(false);
 	}
 
-	RETVAL_FALSE;
-
-	if (PASS == xmysqlnd_crud_collection_find__set_offset(find_op, position)) {
-		ZVAL_COPY(return_value, object_zv);
-	}
-
-	DBG_VOID_RETURN;
+	DBG_RETURN(PASS == xmysqlnd_crud_collection_find__set_offset(find_op, position));
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::bind() */
-void Collection_find::bind(
-	HashTable* bind_variables,
-	zval* return_value)
+bool Collection_find::bind(const util::zvalue& bind_variables)
 {
 	DBG_ENTER("mysqlx_collection__find::bind");
 
-	RETVAL_FALSE;
-
-	zend_string* key{nullptr};
-	zval* val{nullptr};
-	MYSQLX_HASH_FOREACH_STR_KEY_VAL(bind_variables, key, val) {
-		if (key) {
-			const MYSQLND_CSTRING variable = { ZSTR_VAL(key), ZSTR_LEN(key) };
-			if (FAIL == xmysqlnd_crud_collection_find__bind_value(find_op, variable, val)) {
-				RAISE_EXCEPTION(err_msg_bind_fail);
-				DBG_VOID_RETURN;
-			}
+	for (const auto& variable_value : bind_variables) {
+		const util::zvalue& var_name{ variable_value.first };
+		if (!var_name.is_string()) {
+			RAISE_EXCEPTION(err_msg_bind_fail);
+			DBG_RETURN(false);
 		}
-	} ZEND_HASH_FOREACH_END();
-	ZVAL_COPY(return_value, object_zv);
+		const util::zvalue& var_value{ variable_value.second };
+		if (FAIL == xmysqlnd_crud_collection_find__bind_value(find_op, var_name.to_string(), var_value.ptr())) {
+			RAISE_EXCEPTION(err_msg_bind_fail);
+			DBG_RETURN(false);
+		}
+	}
 
-	DBG_VOID_RETURN;
+	DBG_RETURN(true);
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::lock_shared() */
-void Collection_find::lock_shared(zval* return_value, int lock_waiting_option)
+bool Collection_find::lock_shared(int lock_waiting_option)
 {
 	DBG_ENTER("mysqlx_collection__find::lock_shared");
-
-	RETVAL_FALSE;
-
-	if ((xmysqlnd_crud_collection_find__enable_lock_shared(find_op) == PASS)
-		&& (xmysqlnd_crud_collection_find_set_lock_waiting_option(find_op, lock_waiting_option) == PASS))
-	{
-		ZVAL_COPY(return_value, object_zv);
-	}
-
-	DBG_VOID_RETURN;
+	DBG_RETURN((xmysqlnd_crud_collection_find__enable_lock_shared(find_op) == PASS)
+		&& (xmysqlnd_crud_collection_find_set_lock_waiting_option(find_op, lock_waiting_option) == PASS));
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::lock_exclusive() */
-void Collection_find::lock_exclusive(zval* return_value, int lock_waiting_option)
+bool Collection_find::lock_exclusive(int lock_waiting_option)
 {
 	DBG_ENTER("mysqlx_collection__find::lock_exclusive");
-
-	RETVAL_FALSE;
-
-	if ((xmysqlnd_crud_collection_find__enable_lock_exclusive(find_op) == PASS)
-		&& (xmysqlnd_crud_collection_find_set_lock_waiting_option(find_op, lock_waiting_option) == PASS))
-	{
-		ZVAL_COPY(return_value, object_zv);
-	}
-
-	DBG_VOID_RETURN;
+	DBG_RETURN((xmysqlnd_crud_collection_find__enable_lock_exclusive(find_op) == PASS)
+		&& (xmysqlnd_crud_collection_find_set_lock_waiting_option(find_op, lock_waiting_option) == PASS));
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::execute() */
-void Collection_find::execute(zval* return_value)
+void Collection_find::execute(zval* resultset)
 {
-	execute(MYSQLX_EXECUTE_FLAG_BUFFERED, return_value);
+	execute(MYSQLX_EXECUTE_FLAG_BUFFERED, resultset);
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::execute() */
 void Collection_find::execute(
 	zend_long flags,
-	zval* return_value)
+	zval* resultset)
 {
 	DBG_ENTER("mysqlx_collection__find::execute");
 
-	RETVAL_FALSE;
-
 	xmysqlnd_crud_collection_find_verify_is_initialized(find_op);
 
 	xmysqlnd_stmt* stmt{ collection->find(find_op) };
 	if (stmt) {
-		zval stmt_zv;
-		ZVAL_UNDEF(&stmt_zv);
-		mysqlx_new_stmt(&stmt_zv, stmt);
-		if (Z_TYPE(stmt_zv) == IS_NULL) {
+		util::zvalue stmt_zv;
+		mysqlx_new_stmt(stmt_zv.ptr(), stmt);
+		if (stmt_zv.is_null()) {
 			xmysqlnd_stmt_free(stmt, nullptr, nullptr);
+		} else if (stmt_zv.is_object()) {
+			mysqlx_statement_execute_read_response(
+				Z_MYSQLX_P(stmt_zv.ptr()), flags, MYSQLX_RESULT_DOC, resultset);
 		}
-		if (Z_TYPE(stmt_zv) == IS_OBJECT) {
-			zval zv;
-			ZVAL_UNDEF(&zv);
-			mysqlx_statement_execute_read_response(Z_MYSQLX_P(&stmt_zv), flags, MYSQLX_RESULT_DOC, &zv);
-
-			ZVAL_COPY(return_value, &zv);
-			zval_dtor(&zv);
-		}
-		zval_ptr_dtor(&stmt_zv);
 	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::execute() */
 Mysqlx::Crud::Find* Collection_find::get_stmt()
 {
 	if (!find_op
@@ -474,42 +373,38 @@ Mysqlx::Crud::Find* Collection_find::get_stmt()
 	Mysqlx::Crud::Find* msg = static_cast<Mysqlx::Crud::Find*>(msg_shell.message);
 	return msg;
 }
-/* }}} */
 
 //------------------------------------------------------------------------------
 
 
-/* {{{ mysqlx_collection__find::__construct */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, __construct)
 {
 	UNUSED_INTERNAL_FUNCTION_PARAMETERS();
 }
-/* }}} */
 
-/* {{{ mysqlx_collection__find::fields */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, fields)
 {
-	zval* object_zv{nullptr};
-	const zval* fields{nullptr};
-
 	DBG_ENTER("mysqlx_collection__find::fields");
 
+	zval* object_zv{nullptr};
+	zval* raw_fields{nullptr};
+
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Oz",
 												&object_zv, collection_find_class_entry,
-												(zval *) &fields))
+												&raw_fields))
 	{
 		DBG_VOID_RETURN;
 	}
 
 	Collection_find& coll_find = util::fetch_data_object<Collection_find>(object_zv);
-	coll_find.fields(fields, return_value);
+	util::zvalue fields(raw_fields);
+	if (coll_find.fields(fields)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ mysqlx_collection__find__add_sort_or_grouping */
 static void
 mysqlx_collection__find__add_sort_or_grouping(
 	INTERNAL_FUNCTION_PARAMETERS,
@@ -518,27 +413,26 @@ mysqlx_collection__find__add_sort_or_grouping(
 	DBG_ENTER("mysqlx_collection__find__add_sort_or_grouping");
 
 	zval* object_zv{nullptr};
-	zval* sort_expr{nullptr};
+	zval* sort_expressions{nullptr};
 	int num_of_expr{0};
 
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "O+",
 									&object_zv,
 									collection_find_class_entry,
-									&sort_expr,
+									&sort_expressions,
 									&num_of_expr))
 	{
 		DBG_VOID_RETURN;
 	}
 
 	Collection_find& coll_find = util::fetch_data_object<Collection_find>(object_zv);
-	coll_find.add_operation(op_type, sort_expr, num_of_expr, return_value);
+	if (coll_find.add_operation(op_type, sort_expressions, num_of_expr)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::sort() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, sort)
 {
 	DBG_ENTER("mysqlx_collection__find::sort");
@@ -547,10 +441,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, sort)
 		Collection_find::Operation::Sort);
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::groupBy() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, groupBy)
 {
 	DBG_ENTER("mysqlx_collection__find::groupBy");
@@ -560,41 +451,38 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, groupBy)
 		Collection_find::Operation::Group_by);
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::having() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, having)
 {
-	zval* object_zv{nullptr};
-	MYSQLND_CSTRING search_condition = {nullptr, 0};
-
 	DBG_ENTER("mysqlx_collection__find::having");
+
+	zval* object_zv{nullptr};
+	util::string_view search_condition;
+
 	php_error_docref(nullptr, E_WARNING, "find.having is a deprecated function since MySQL 8.0.16");
 
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Os",
 												&object_zv, collection_find_class_entry,
-												&(search_condition.s), &(search_condition.l)))
+												&(search_condition.str), &(search_condition.len)))
 	{
 		DBG_VOID_RETURN;
 	}
 
 	Collection_find& coll_find = util::fetch_data_object<Collection_find>(object_zv);
-	coll_find.having(search_condition, return_value);
+	if (coll_find.having(search_condition)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::limit() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, limit)
 {
+	DBG_ENTER("mysqlx_collection__find::limit");
+
 	zval* object_zv{nullptr};
 	zend_long rows{0};
 
-	DBG_ENTER("mysqlx_collection__find::limit");
-
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Ol",
 												&object_zv, collection_find_class_entry,
 												&rows))
@@ -603,21 +491,20 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, limit)
 	}
 
 	Collection_find& coll_find = util::fetch_data_object<Collection_find>(object_zv);
-	coll_find.limit(rows, return_value);
+	if (coll_find.limit(rows)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::offset() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, offset)
 {
+	DBG_ENTER("mysqlx_collection__find::offset");
+
 	zval* object_zv{nullptr};
 	zend_long position{0};
 
-	DBG_ENTER("mysqlx_collection__find::offset");
-
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Ol",
 												&object_zv, collection_find_class_entry,
 												&position))
@@ -631,37 +518,36 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, offset)
 	}
 
 	Collection_find& coll_find = util::fetch_data_object<Collection_find>(object_zv);
-	coll_find.offset(position, return_value);
+	if (coll_find.offset(position)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::bind() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, bind)
 {
-	zval* object_zv{nullptr};
-	HashTable* bind_variables{nullptr};
-
 	DBG_ENTER("mysqlx_collection__find::bind");
 
-	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Oh",
+	zval* object_zv{nullptr};
+	zval* bind_vars{nullptr};
+
+	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Oz",
 												&object_zv, collection_find_class_entry,
-												&bind_variables))
+												&bind_vars))
 	{
 		DBG_VOID_RETURN;
 	}
 
 	Collection_find& coll_find = util::fetch_data_object<Collection_find>(object_zv);
-	coll_find.bind(bind_variables, return_value);
+	util::zvalue bind_variables(bind_vars);
+	if (coll_find.bind(bind_variables)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::lockShared() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, lockShared)
 {
 	DBG_ENTER("mysqlx_collection__find::lockShared");
@@ -676,14 +562,13 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, lockShared)
 	}
 
 	Collection_find& coll_find = util::fetch_data_object<Collection_find>(object_zv);
-	coll_find.lock_shared(return_value, static_cast<int>(lock_waiting_option));
+	if (coll_find.lock_shared(static_cast<int>(lock_waiting_option))) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::lockExclusive() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, lockExclusive)
 {
 	DBG_ENTER("mysqlx_collection__find::lockExclusive");
@@ -698,21 +583,20 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, lockExclusive)
 	}
 
 	Collection_find& coll_find = util::fetch_data_object<Collection_find>(object_zv);
-	coll_find.lock_exclusive(return_value, static_cast<int>(lock_waiting_option));
+	if (coll_find.lock_exclusive(static_cast<int>(lock_waiting_option))) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__find::execute() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, execute)
 {
+	DBG_ENTER("mysqlx_collection__find::execute");
+
 	zval* object_zv{nullptr};
 	zend_long flags{MYSQLX_EXECUTE_FLAG_BUFFERED};
 
-	DBG_ENTER("mysqlx_collection__find::execute");
-
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "O|l",
 												&object_zv, collection_find_class_entry,
 												&flags))
@@ -725,10 +609,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__find, execute)
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ mysqlx_collection__find_methods[] */
 static const zend_function_entry mysqlx_collection__find_methods[] = {
 	PHP_ME(mysqlx_collection__find, __construct, nullptr, ZEND_ACC_PRIVATE)
 
@@ -745,8 +626,6 @@ static const zend_function_entry mysqlx_collection__find_methods[] = {
 
 	{nullptr, nullptr, nullptr}
 };
-/* }}} */
-
 
 static zend_object_handlers collection_find_handlers;
 static HashTable collection_find_properties;
@@ -756,16 +635,12 @@ const st_mysqlx_property_entry collection_find_property_entries[] =
 	{{nullptr,	0}, nullptr, nullptr}
 };
 
-/* {{{ mysqlx_collection__find_free_storage */
 static void
 mysqlx_collection__find_free_storage(zend_object* object)
 {
 	util::free_object<Collection_find>(object);
 }
-/* }}} */
 
-
-/* {{{ php_mysqlx_collection__find_object_allocator */
 static zend_object *
 php_mysqlx_collection__find_object_allocator(zend_class_entry* class_type)
 {
@@ -776,10 +651,7 @@ php_mysqlx_collection__find_object_allocator(zend_class_entry* class_type)
 		&collection_find_properties);
 	DBG_RETURN(&mysqlx_object->zo);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_register_collection__find_class */
 void
 mysqlx_register_collection__find_class(UNUSED_INIT_FUNC_ARGS, zend_object_handlers* mysqlx_std_object_handlers)
 {
@@ -798,19 +670,13 @@ mysqlx_register_collection__find_class(UNUSED_INIT_FUNC_ARGS, zend_object_handle
 		mysqlx_crud_operation_limitable_interface_entry,
 		mysqlx_crud_operation_sortable_interface_entry);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_unregister_collection__find_class */
 void
 mysqlx_unregister_collection__find_class(UNUSED_SHUTDOWN_FUNC_ARGS)
 {
 	zend_hash_destroy(&collection_find_properties);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_new_collection__find */
 void
 mysqlx_new_collection__find(
 	zval * return_value,
@@ -821,7 +687,7 @@ mysqlx_new_collection__find(
 	if (SUCCESS == object_init_ex(return_value, collection_find_class_entry) && IS_OBJECT == Z_TYPE_P(return_value)) {
 		const st_mysqlx_object* const mysqlx_object = Z_MYSQLX_P(return_value);
 		Collection_find* const coll_find = static_cast<Collection_find*>(mysqlx_object->ptr);
-		if (!coll_find || !coll_find->init(return_value, collection, search_expression)) {
+		if (!coll_find || !coll_find->init(collection, search_expression)) {
 			DBG_ERR("Error");
 			php_error_docref(nullptr, E_WARNING, "invalid coll_find of class %s", ZSTR_VAL(mysqlx_object->zo.ce->name));
 			zval_ptr_dtor(return_value);
@@ -830,26 +696,13 @@ mysqlx_new_collection__find(
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ get_stmt_from_collection_find */
 Mysqlx::Crud::Find* get_stmt_from_collection_find(zval* object_zv)
 {
 	Collection_find& coll_find = util::fetch_data_object<Collection_find>(object_zv);
 	return coll_find.get_stmt();
 }
-/* }}} */
 
 } // namespace devapi
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
