@@ -13,6 +13,8 @@
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Andrey Hristov <andrey@php.net>                             |
+  |          Filip Janiszewski <fjanisze@php.net>                        |
+  |          Darek Slusarczyk <marines@php.net>                          |
   +----------------------------------------------------------------------+
 */
 #include "php_api.h"
@@ -38,6 +40,7 @@
 #include "util/allocator.h"
 #include "util/json_utils.h"
 #include "util/object.h"
+#include "util/value.h"
 #include "util/zend_utils.h"
 
 namespace mysqlx {
@@ -49,7 +52,7 @@ using namespace drv;
 static zend_class_entry* collection_modify_class_entry;
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_collection__modify__sort, 0, ZEND_RETURN_VALUE, 1)
-	ZEND_ARG_INFO(no_pass_by_ref, sort_expr)
+	ZEND_ARG_INFO(no_pass_by_ref, sort_expressions)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_collection__modify__limit, 0, ZEND_RETURN_VALUE, 1)
@@ -99,15 +102,12 @@ ZEND_END_ARG_INFO()
 //------------------------------------------------------------------------------
 
 
-/* {{{ Collection_modify::init() */
 bool Collection_modify::init(
-	zval* obj_zv,
 	xmysqlnd_collection* coll,
 	const util::string_view& search_expression)
 {
-	if (!obj_zv || !coll || search_expression.empty()) return false;
+	if (!coll || search_expression.empty()) return false;
 
-	object_zv = obj_zv;
 	collection = coll->get_reference();
 	modify_op = xmysqlnd_crud_collection_modify__create(
 		mnd_str2c(collection->get_schema()->get_name()),
@@ -116,12 +116,9 @@ bool Collection_modify::init(
 	if (!modify_op) return false;
 
 	return xmysqlnd_crud_collection_modify__set_criteria(
-		modify_op, search_expression.to_std_string()) == PASS;
+		modify_op, search_expression.to_std_string());
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::~Collection_modify() */
 Collection_modify::~Collection_modify()
 {
 	if (modify_op) {
@@ -132,438 +129,308 @@ Collection_modify::~Collection_modify()
 		xmysqlnd_collection_free(collection, nullptr, nullptr);
 	}
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::sort() */
-void Collection_modify::sort(
-	zval* sort_expr,
-	int num_of_expr,
-	zval* return_value)
+bool Collection_modify::sort(
+	zval* sort_expressions,
+	int num_of_expr)
 {
 	DBG_ENTER("Collection_modify::sort");
 
-	if (!sort_expr) {
-		DBG_VOID_RETURN;
+	if (!sort_expressions) {
+		DBG_RETURN(false);
 	}
 
-	RETVAL_FALSE;
-
-	for( int i{0}; i < num_of_expr ; ++i ) {
-		switch (Z_TYPE(sort_expr[i])) {
-		case IS_STRING:
+	for( int i{0}; i < num_of_expr; ++i ) {
+		const util::zvalue sort_expr(sort_expressions[i]);
+		switch (sort_expr.type()) {
+		case util::zvalue::Type::String:
 			{
-				const MYSQLND_CSTRING sort_expr_str = { Z_STRVAL(sort_expr[i]),
-												Z_STRLEN(sort_expr[i]) };
-				if (PASS == xmysqlnd_crud_collection_modify__add_sort(modify_op,
+				const MYSQLND_CSTRING sort_expr_str{ sort_expr.c_str(), sort_expr.length() };
+				if (!xmysqlnd_crud_collection_modify__add_sort(modify_op,
 															sort_expr_str)) {
-					ZVAL_COPY(return_value, object_zv);
+					RAISE_EXCEPTION(err_msg_add_sort_fail);
+					DBG_RETURN(false);
 				}
 			}
 			break;
-		case IS_ARRAY:
+		case util::zvalue::Type::Array:
 			{
-				zval* entry{nullptr};
-				MYSQLX_HASH_FOREACH_VAL(Z_ARRVAL(sort_expr[i]), entry) {
-					const MYSQLND_CSTRING sort_expr_str = { Z_STRVAL_P(entry),
-													Z_STRLEN_P(entry) };
-					if (Z_TYPE_P(entry) != IS_STRING) {
+				for (auto it{ sort_expr.vbegin() }; it != sort_expr.vend(); ++it) {
+					const util::zvalue& sort_expr_entry(*it);
+					if (!sort_expr_entry.is_string()) {
 						RAISE_EXCEPTION(err_msg_wrong_param_1);
-						DBG_VOID_RETURN;
+						DBG_RETURN(false);
 					}
-					if (FAIL == xmysqlnd_crud_collection_modify__add_sort(modify_op,
-														sort_expr_str)) {
+					const MYSQLND_CSTRING sort_expr_str{
+						sort_expr_entry.c_str(), sort_expr_entry.length() };
+					if (!xmysqlnd_crud_collection_modify__add_sort(modify_op,
+															sort_expr_str)) {
 						RAISE_EXCEPTION(err_msg_add_sort_fail);
-						DBG_VOID_RETURN;
+						DBG_RETURN(false);
 					}
-				} ZEND_HASH_FOREACH_END();
-				ZVAL_COPY(return_value, object_zv);
+				}
 			}
 			break;
 		default:
 			RAISE_EXCEPTION(err_msg_wrong_param_3);
+			DBG_RETURN(false);
 			break;
 		}
 	}
-	DBG_VOID_RETURN;
+	DBG_RETURN(true);
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::limit() */
-void Collection_modify::limit(
-	zend_long rows,
-	zval* return_value)
+bool Collection_modify::limit(zend_long rows)
 {
 	DBG_ENTER("Collection_modify::limit");
 
 	if (rows < 0) {
 		RAISE_EXCEPTION(err_msg_wrong_param_2);
-		DBG_VOID_RETURN;
+		DBG_RETURN(false);
 	}
 
-	RETVAL_FALSE;
-
-	if (PASS == xmysqlnd_crud_collection_modify__set_limit(modify_op, rows)) {
-		ZVAL_COPY(return_value, object_zv);
-	}
-
-	DBG_VOID_RETURN;
+	DBG_RETURN(xmysqlnd_crud_collection_modify__set_limit(modify_op, rows));
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::skip() */
-void Collection_modify::skip(
-	zend_long position,
-	zval* return_value)
+bool Collection_modify::skip(zend_long position)
 {
 	DBG_ENTER("Collection_modify::skip");
 
 	if (position < 0) {
 		RAISE_EXCEPTION(err_msg_wrong_param_2);
-		DBG_VOID_RETURN;
+		DBG_RETURN(false);
 	}
 
-	RETVAL_FALSE;
-
-	if (PASS == xmysqlnd_crud_collection_modify__set_skip(modify_op, position)) {
-		ZVAL_COPY(return_value, object_zv);
-	}
-
-	DBG_VOID_RETURN;
+	DBG_RETURN(xmysqlnd_crud_collection_modify__set_skip(modify_op, position));
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::bind() */
-void Collection_modify::bind(
-	HashTable* bind_variables,
-	zval* return_value)
+bool Collection_modify::bind(const util::zvalue& bind_variables)
 {
 	DBG_ENTER("Collection_modify::bind");
 
-	RETVAL_FALSE;
-
-	zend_string* key{nullptr};
-	zval* val{nullptr};
-	MYSQLX_HASH_FOREACH_STR_KEY_VAL(bind_variables, key, val) {
-		if (key) {
-			const MYSQLND_CSTRING variable = { ZSTR_VAL(key), ZSTR_LEN(key) };
-			if (FAIL == xmysqlnd_crud_collection_modify__bind_value(modify_op, variable, val)) {
-				RAISE_EXCEPTION(err_msg_bind_fail);
-				DBG_VOID_RETURN;
-			}
+	for (const auto& variable_value : bind_variables) {
+		const util::zvalue& var_name{ variable_value.first };
+		if (!var_name.is_string()) {
+			RAISE_EXCEPTION(err_msg_bind_fail);
+			DBG_RETURN(false);
 		}
-	} ZEND_HASH_FOREACH_END();
-	ZVAL_COPY(return_value, object_zv);
-
-	DBG_VOID_RETURN;
-}
-/* }}} */
-
-
-/* {{{ Collection_modify::add_operation */
-void Collection_modify::add_operation(
-	Operation operation,
-	const util::string_view& path,
-	const bool is_document,
-	zval* raw_value,
-	zval* return_value)
-{
-	DBG_ENTER("Collection_modify::add_operation");
-
-	RETVAL_FALSE;
-
-	zend_bool is_expression{FALSE};
-
-	zval converted_value;
-	ZVAL_UNDEF(&converted_value);
-
-	const zval* value = raw_value;
-
-	switch (Z_TYPE_P(value)) {
-		case IS_OBJECT:
-			if (operation == Collection_modify::Operation::Set) {
-				if (is_a_mysqlx_expression(value)) {
-					/* get the string */
-					value = get_mysqlx_expression(value);
-					is_expression = TRUE;
-				}
-				break;
-			}
-			/* fall-through */
-		case IS_STRING:
-		case IS_DOUBLE:
-		case IS_TRUE:
-		case IS_FALSE:
-		case IS_LONG:
-		case IS_NULL:
-			break;
-
-		case IS_ARRAY:
-			util::json::to_zv_string(raw_value, &converted_value);
-			value = &converted_value;
-			break;
-
-		default:{
-			RAISE_EXCEPTION(err_msg_invalid_type);
-			DBG_VOID_RETURN;
+		const util::zvalue& var_value{ variable_value.second };
+		if (!xmysqlnd_crud_collection_modify__bind_value(modify_op, var_name.to_string(), var_value.ptr())) {
+			RAISE_EXCEPTION(err_msg_bind_fail);
+			DBG_RETURN(false);
 		}
-
 	}
 
-	RETVAL_FALSE;
+	DBG_RETURN(true);
+}
 
-	enum_func_status ret{FAIL};
-	const MYSQLND_CSTRING& path_nd = path.to_nd_cstr();
-	switch (operation) {
-		case Operation::Set:
-			ret = xmysqlnd_crud_collection_modify__set(modify_op, path_nd, value, is_expression, is_document);
+drv::Modify_value Collection_modify::prepare_value(
+	const util::string_view& path,
+	util::zvalue value,
+	bool validate_array)
+{
+	DBG_ENTER("Collection_modify::prepare_value");
+
+	bool is_expression{ false };
+	bool is_document{ false };
+
+	switch (value.type()) {
+		case util::zvalue::Type::Object:
+			if (is_a_mysqlx_expression(value.ptr())) {
+				value = get_mysqlx_expression(value.ptr());
+				is_expression = true;
+			}
 			break;
 
-		case Operation::Replace:
-			ret = xmysqlnd_crud_collection_modify__replace(modify_op, path_nd, value, is_expression, is_document);
+		case util::zvalue::Type::Double:
+		case util::zvalue::Type::True:
+		case util::zvalue::Type::False:
+		case util::zvalue::Type::Long:
+		case util::zvalue::Type::Null:
 			break;
 
-		case Operation::Array_insert:
-			ret = xmysqlnd_crud_collection_modify__array_insert(modify_op, path_nd, value);
+		case util::zvalue::Type::String:
+			if (util::json::can_be_document(value) || util::json::can_be_array(value)) {
+				is_document = true;
+			} else if (util::json::can_be_binding(value)) {
+				is_expression = true;
+			}
 			break;
 
-		case Operation::Array_append:
-			ret = xmysqlnd_crud_collection_modify__array_append(modify_op, path_nd, value);
+		case util::zvalue::Type::Array:
+			value = util::json::to_zv_string(value);
+			is_document = true;
 			break;
 
 		default:
-			assert(!"unknown collection_modify field operation");
+			throw util::xdevapi_exception(util::xdevapi_exception::Code::invalid_type);
 	}
 
-	if (PASS == ret) {
-		ZVAL_COPY(return_value, object_zv);
-	}
-
-	zval_dtor(&converted_value);
-
-	DBG_VOID_RETURN;
+	drv::Modify_value result{ path, value, is_expression, is_document, validate_array };
+	DBG_RETURN(result);
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::set() */
-void Collection_modify::set(
+bool Collection_modify::set(
 	const util::string_view& path,
-	const bool is_document,
-	zval* value,
-	zval* return_value)
+	zval* value)
 {
 	DBG_ENTER("Collection_modify::set");
-	add_operation(Operation::Set, path, is_document, value, return_value);
-	DBG_VOID_RETURN;
+	DBG_RETURN(xmysqlnd_crud_collection_modify__set(modify_op, prepare_value(path, value)));
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::unset() */
-void Collection_modify::unset(
+bool Collection_modify::unset(
 	zval* variables,
-	int num_of_variables,
-	zval* return_value)
+	int num_of_variables)
 {
 	DBG_ENTER("Collection_modify::unset");
 
-	RETVAL_FALSE;
-
 	if (num_of_variables <= 0) {
-		DBG_VOID_RETURN;
+		DBG_RETURN(false);
 	}
 
 	for (int i{0}; i < num_of_variables; ++i) {
-		switch (Z_TYPE(variables[i]))
+		const util::zvalue variable(variables[i]);
+		switch (variable.type())
 		{
-		case IS_STRING:
+		case util::zvalue::Type::String:
 			{
-				const MYSQLND_CSTRING variable = { Z_STRVAL(variables[i]),
-										Z_STRLEN(variables[i]) };
-				if (FAIL == xmysqlnd_crud_collection_modify__unset(modify_op,
-																variable)) {
-						RAISE_EXCEPTION(err_msg_unset_fail);
+				const util::string_view path{ variable.to_string_view() };
+				if (!xmysqlnd_crud_collection_modify__unset(modify_op, path)) {
+					RAISE_EXCEPTION(err_msg_unset_fail);
+					DBG_RETURN(false);
 				}
 			}
 			break;
-		case IS_ARRAY:
+
+		case util::zvalue::Type::Array:
 			{
-				zval* entry{nullptr};
-				MYSQLX_HASH_FOREACH_VAL(Z_ARRVAL(variables[i]), entry) {
-					if (Z_TYPE_P(entry) != IS_STRING) {
+				for (auto it{ variable.vbegin() }; it != variable.vend(); ++it) {
+					const util::zvalue& variable_entry(*it);
+					if (!variable_entry.is_string()) {
 						RAISE_EXCEPTION(err_msg_wrong_param_1);
-						DBG_VOID_RETURN;
+						DBG_RETURN(false);
 					}
-					const MYSQLND_CSTRING variable = { Z_STRVAL_P(entry),
-											Z_STRLEN_P(entry) };
-					if (FAIL == xmysqlnd_crud_collection_modify__unset(modify_op,
-																	variable)) {
+					const util::string_view path{ variable_entry.to_string_view() };
+					if (!xmysqlnd_crud_collection_modify__unset(modify_op, path)) {
 						RAISE_EXCEPTION(err_msg_unset_fail);
-						DBG_VOID_RETURN;
+						DBG_RETURN(false);
 					}
-				} ZEND_HASH_FOREACH_END();
+				}
 			}
 			break;
+
 		default:
 			RAISE_EXCEPTION(err_msg_wrong_param_3);
+			DBG_RETURN(false);
 			break;
 		}
 	}
 
-	ZVAL_COPY(return_value, object_zv);
-	DBG_VOID_RETURN;
+	DBG_RETURN(true);
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::replace() */
-void Collection_modify::replace(
+bool Collection_modify::replace(
 	const util::string_view& path,
-	zval* value,
-	zval* return_value)
+	zval* value)
 {
 	DBG_ENTER("Collection_modify::replace");
-	add_operation(Operation::Replace, path, false, value, return_value);
-	DBG_VOID_RETURN;
+	DBG_RETURN(xmysqlnd_crud_collection_modify__replace(modify_op, prepare_value(path, value)));
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::patch() */
-void Collection_modify::patch(
-	const util::string_view &document_contents,
-	zval* return_value)
+bool Collection_modify::patch(const util::string_view& document_contents)
 {
 	DBG_ENTER("Collection_modify::patch");
-
-	RETVAL_FALSE;
-
-	MYSQLND_CSTRING emptyDocPath = { nullptr, 0 };
-	zval zvDocumentContents;
-	document_contents.to_zval(&zvDocumentContents);
-	if (FAIL == xmysqlnd_crud_collection_modify__patch(modify_op, emptyDocPath, &zvDocumentContents)) {
+	const util::string_view Empty_doc_path;
+	if (!xmysqlnd_crud_collection_modify__patch(
+		modify_op, prepare_value(Empty_doc_path, document_contents))) {
 		RAISE_EXCEPTION(err_msg_merge_fail);
+		DBG_RETURN(false);
 	}
-	ZVAL_COPY(return_value, object_zv);
-
-	DBG_VOID_RETURN;
+	DBG_RETURN(true);
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::arrayInsert() */
-void Collection_modify::arrayInsert(
+bool Collection_modify::array_insert(
 	const util::string_view& path,
-	zval* value,
-	zval* return_value)
+	zval* value)
 {
-	DBG_ENTER("Collection_modify::arrayInsert");
-	add_operation(Operation::Array_insert, path, true, value, return_value);
-	DBG_VOID_RETURN;
+	DBG_ENTER("Collection_modify::array_insert");
+	DBG_RETURN(xmysqlnd_crud_collection_modify__array_insert(modify_op, prepare_value(path, value, true)));
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::arrayAppend() */
-void Collection_modify::arrayAppend(
+bool Collection_modify::array_append(
 	const util::string_view& path,
-	zval* value,
-	zval* return_value)
+	zval* value)
 {
-	DBG_ENTER("Collection_modify::arrayAppend");
-	add_operation(Operation::Array_append, path, false, value, return_value);
-	DBG_VOID_RETURN;
+	DBG_ENTER("Collection_modify::array_append");
+	DBG_RETURN(xmysqlnd_crud_collection_modify__array_append(modify_op, prepare_value(path, value)));
 }
-/* }}} */
 
-
-/* {{{ Collection_modify::execute() */
-void Collection_modify::execute(
-	zval* return_value)
+void Collection_modify::execute(zval* resultset)
 {
 	DBG_ENTER("Collection_modify::execute");
 
-	RETVAL_FALSE;
-
 	DBG_INF_FMT("modify_op=%p collection=%p", modify_op, collection);
-	if (FALSE == xmysqlnd_crud_collection_modify__is_initialized(modify_op)) {
+	if (!xmysqlnd_crud_collection_modify__is_initialized(modify_op)) {
 		RAISE_EXCEPTION(err_msg_modify_fail);
 	} else {
 		xmysqlnd_stmt* stmt = collection->modify(modify_op);
 		if (stmt) {
-			zval stmt_zv;
-			ZVAL_UNDEF(&stmt_zv);
-			mysqlx_new_stmt(&stmt_zv, stmt);
-			if (Z_TYPE(stmt_zv) == IS_NULL) {
-				xmysqlnd_stmt_free(stmt, nullptr, nullptr);
-			}
-			if (Z_TYPE(stmt_zv) == IS_OBJECT) {
-				zval zv;
-				ZVAL_UNDEF(&zv);
-				zend_long flags{0};
-				mysqlx_statement_execute_read_response(Z_MYSQLX_P(&stmt_zv), flags, MYSQLX_RESULT, &zv);
+			util::zvalue stmt_zv;
+			mysqlx_new_stmt(stmt_zv.ptr(), stmt);
 
-				ZVAL_COPY(return_value, &zv);
-				zval_dtor(&zv);
+			if (stmt_zv.is_null()) {
+				xmysqlnd_stmt_free(stmt, nullptr, nullptr);
+			} else if (stmt_zv.is_object()) {
+				zend_long flags{0};
+				mysqlx_statement_execute_read_response(
+					Z_MYSQLX_P(stmt_zv.ptr()), flags, MYSQLX_RESULT, resultset);
 			}
-			zval_ptr_dtor(&stmt_zv);
 		}
 	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
-
 
 //------------------------------------------------------------------------------
 
 
-/* {{{ mysqlx_collection__modify::__construct */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, __construct)
 {
 	UNUSED_INTERNAL_FUNCTION_PARAMETERS();
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__modify::sort() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, sort)
 {
-	zval* object_zv{nullptr};
-	zval* sort_expr{nullptr};
-	int num_of_expr{0};
-
 	DBG_ENTER("mysqlx_collection__modify::sort");
 
+	zval* object_zv{nullptr};
+	zval* sort_expressions{nullptr};
+	int num_of_expr{0};
+
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "O+",
 									&object_zv,
 									collection_modify_class_entry,
-									&sort_expr,
+									&sort_expressions,
 									&num_of_expr))
 	{
 		DBG_VOID_RETURN;
 	}
 
 	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
-	coll_modify.sort(sort_expr, num_of_expr, return_value);
+	if (coll_modify.sort(sort_expressions, num_of_expr)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__modify::limit() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, limit)
 {
+	DBG_ENTER("mysqlx_collection__modify::limit");
+
 	zval* object_zv{nullptr};
 	zend_long rows{0};
 
-	DBG_ENTER("mysqlx_collection__modify::limit");
-
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Ol",
 												&object_zv, collection_modify_class_entry,
 												&rows))
@@ -572,21 +439,20 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, limit)
 	}
 
 	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
-	coll_modify.limit(rows, return_value);
+	if (coll_modify.limit(rows)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__modify::skip() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, skip)
 {
+	DBG_ENTER("mysqlx_collection__modify::skip");
+
 	zval* object_zv{nullptr};
 	zend_long position{0};
 
-	DBG_ENTER("mysqlx_collection__modify::skip");
-
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Ol",
 												&object_zv, collection_modify_class_entry,
 												&position))
@@ -600,96 +466,93 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, skip)
 	}
 
 	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
-	coll_modify.skip(position, return_value);
+	if (coll_modify.skip(position)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__modify::bind() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, bind)
 {
-	zval* object_zv{nullptr};
-	HashTable* bind_variables{nullptr};
-
 	DBG_ENTER("mysqlx_collection__modify::bind");
 
-	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Oh",
-												&object_zv, collection_modify_class_entry,
-												&bind_variables))
-	{
-		DBG_VOID_RETURN;
-	}
-
-	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
-	coll_modify.bind(bind_variables, return_value);
-
-	DBG_VOID_RETURN;
-}
-/* }}} */
-
-
-/* {{{ mysqlx_collection__modify__2_param_op */
-static void
-mysqlx_collection__modify__2_param_op(
-	INTERNAL_FUNCTION_PARAMETERS,
-	const Collection_modify::Operation operation,
-	const bool is_document = false)
-{
 	zval* object_zv{nullptr};
-	zval* value{nullptr};
-	util::string_view path;
+	zval* bind_vars{nullptr};
 
-	DBG_ENTER("mysqlx_collection__modify__2_param_op");
-
-	RETVAL_FALSE;
-
-	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Osz",
+	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Oz",
 												&object_zv, collection_modify_class_entry,
-												&(path.str), &(path.len),
-												&value))
+												&bind_vars))
 	{
 		DBG_VOID_RETURN;
 	}
 
 	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
-	coll_modify.add_operation(operation, path, is_document, value, return_value);
+	util::zvalue bind_variables(bind_vars);
+	if (coll_modify.bind(bind_variables)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__modify::set() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, set)
 {
 	DBG_ENTER("mysqlx_collection__modify::set");
-	mysqlx_collection__modify__2_param_op(
-		INTERNAL_FUNCTION_PARAM_PASSTHRU, Collection_modify::Operation::Set);
+
+	zval* object_zv{nullptr};
+	util::string_view path;
+	zval* value{nullptr};
+
+	if (FAILURE == util::zend::parse_method_parameters(
+		execute_data, getThis(), "Osz",
+		&object_zv, collection_modify_class_entry,
+		&path.str, &path.len,
+		&value))
+	{
+		DBG_VOID_RETURN;
+	}
+
+	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
+	if (coll_modify.set(path, value)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
+
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__modify::replace() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, replace)
 {
 	DBG_ENTER("mysqlx_collection__modify::replace");
-	mysqlx_collection__modify__2_param_op(
-		INTERNAL_FUNCTION_PARAM_PASSTHRU, Collection_modify::Operation::Replace);
+
+	zval* object_zv{nullptr};
+	util::string_view path;
+	zval* value{nullptr};
+
+	if (FAILURE == util::zend::parse_method_parameters(
+		execute_data, getThis(), "Osz",
+		&object_zv, collection_modify_class_entry,
+		&path.str, &path.len,
+		&value))
+	{
+		DBG_VOID_RETURN;
+	}
+
+	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
+	if (coll_modify.replace(path, value)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
+
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-/* {{{ proto mixed mysqlx_collection__modify::patch() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, patch)
 {
+	DBG_ENTER("mysqlx_collection__modify::patch");
+
 	zval* object_zv{nullptr};
 	util::string_view document_contents;
 
-	DBG_ENTER("mysqlx_collection__modify::patch");
-
 	if (FAILURE == util::zend::parse_method_parameters(
 		execute_data, getThis(), "Os",
 		&object_zv, collection_modify_class_entry,
@@ -699,44 +562,71 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, patch)
 	}
 
 	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
-	coll_modify.patch(document_contents, return_value);
+	if (coll_modify.patch(document_contents)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__modify::arrayInsert() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, arrayInsert)
 {
 	DBG_ENTER("mysqlx_collection__modify::arrayInsert");
-	mysqlx_collection__modify__2_param_op(
-		INTERNAL_FUNCTION_PARAM_PASSTHRU, Collection_modify::Operation::Array_insert, true);
+
+	zval* object_zv{nullptr};
+	util::string_view path;
+	zval* value{nullptr};
+
+	if (FAILURE == util::zend::parse_method_parameters(
+		execute_data, getThis(), "Osz",
+		&object_zv, collection_modify_class_entry,
+		&path.str, &path.len,
+		&value))
+	{
+		DBG_VOID_RETURN;
+	}
+
+	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
+	if (coll_modify.array_insert(path, value)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
+
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__modify::arrayAppend() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, arrayAppend)
 {
 	DBG_ENTER("mysqlx_collection__modify::arrayAppend");
-	mysqlx_collection__modify__2_param_op(
-		INTERNAL_FUNCTION_PARAM_PASSTHRU, Collection_modify::Operation::Array_append);
+
+	zval* object_zv{nullptr};
+	util::string_view path;
+	zval* value{nullptr};
+
+	if (FAILURE == util::zend::parse_method_parameters(
+		execute_data, getThis(), "Osz",
+		&object_zv, collection_modify_class_entry,
+		&path.str, &path.len,
+		&value))
+	{
+		DBG_VOID_RETURN;
+	}
+
+	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
+	if (coll_modify.array_append(path, value)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
+
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__modify::unset() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, unset)
 {
+	DBG_ENTER("mysqlx_collection__modify::unset");
+
 	zval* object_zv{nullptr};
 	zval* variables{nullptr};
 	int num_of_variables{0};
 
-	DBG_ENTER("mysqlx_collection__modify::unset");
-
 	if (FAILURE == util::zend::parse_method_parameters(
 		execute_data, getThis(), "O+",
 		&object_zv,
@@ -748,20 +638,19 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, unset)
 	}
 
 	Collection_modify& coll_modify = util::fetch_data_object<Collection_modify>(object_zv);
-	coll_modify.unset(variables, num_of_variables, return_value);
+	if (coll_modify.unset(variables, num_of_variables)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__modify::execute() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, execute)
 {
-	zval* object_zv{nullptr};
-
 	DBG_ENTER("mysqlx_collection__modify::execute");
 
+	zval* object_zv{nullptr};
+
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "O",
 												&object_zv, collection_modify_class_entry))
 	{
@@ -773,10 +662,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__modify, execute)
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ mysqlx_collection__modify_methods[] */
 static const zend_function_entry mysqlx_collection__modify_methods[] = {
 	PHP_ME(mysqlx_collection__modify, 	__construct,	nullptr,												ZEND_ACC_PRIVATE)
 
@@ -796,8 +682,6 @@ static const zend_function_entry mysqlx_collection__modify_methods[] = {
 
 	{nullptr, nullptr, nullptr}
 };
-/* }}} */
-
 
 static zend_object_handlers collection_modify_handlers;
 static HashTable collection_modify_properties;
@@ -807,16 +691,12 @@ const st_mysqlx_property_entry collection_modify_property_entries[] =
 	{{nullptr,	0}, nullptr, nullptr}
 };
 
-/* {{{ mysqlx_collection__modify_free_storage */
 static void
 mysqlx_collection__modify_free_storage(zend_object* object)
 {
 	util::free_object<Collection_modify>(object);
 }
-/* }}} */
 
-
-/* {{{ php_mysqlx_collection__modify_object_allocator */
 static zend_object *
 php_mysqlx_collection__modify_object_allocator(zend_class_entry* class_type)
 {
@@ -827,10 +707,7 @@ php_mysqlx_collection__modify_object_allocator(zend_class_entry* class_type)
 		&collection_modify_properties);
 	DBG_RETURN(&mysqlx_object->zo);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_register_collection__modify_class */
 void
 mysqlx_register_collection__modify_class(UNUSED_INIT_FUNC_ARGS, zend_object_handlers* mysqlx_std_object_handlers)
 {
@@ -850,19 +727,13 @@ mysqlx_register_collection__modify_class(UNUSED_INIT_FUNC_ARGS, zend_object_hand
 		mysqlx_crud_operation_skippable_interface_entry,
 		mysqlx_crud_operation_sortable_interface_entry);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_unregister_collection__modify_class */
 void
 mysqlx_unregister_collection__modify_class(UNUSED_SHUTDOWN_FUNC_ARGS)
 {
 	zend_hash_destroy(&collection_modify_properties);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_new_collection__modify */
 void
 mysqlx_new_collection__modify(
 	zval* return_value,
@@ -874,7 +745,7 @@ mysqlx_new_collection__modify(
 	if (SUCCESS == object_init_ex(return_value, collection_modify_class_entry) && IS_OBJECT == Z_TYPE_P(return_value)) {
 		const st_mysqlx_object* const mysqlx_object = Z_MYSQLX_P(return_value);
 		Collection_modify* const coll_modify = static_cast<Collection_modify*>(mysqlx_object->ptr);
-		if (!coll_modify || !coll_modify->init(return_value, collection, search_expression)) {
+		if (!coll_modify || !coll_modify->init(collection, search_expression)) {
 			DBG_ERR("Error");
 			php_error_docref(nullptr, E_WARNING, "invalid object of class %s", ZSTR_VAL(mysqlx_object->zo.ce->name));
 			zval_ptr_dtor(return_value);
@@ -884,17 +755,7 @@ mysqlx_new_collection__modify(
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
 } // namespace devapi
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
