@@ -13,6 +13,8 @@
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Andrey Hristov <andrey@php.net>                             |
+  |          Filip Janiszewski <fjanisze@php.net>                        |
+  |          Darek Slusarczyk <marines@php.net>                          |
   +----------------------------------------------------------------------+
 */
 #include "php_api.h"
@@ -34,6 +36,7 @@
 #include "mysqlx_collection__remove.h"
 #include "util/allocator.h"
 #include "util/object.h"
+#include "util/value.h"
 #include "util/zend_utils.h"
 
 namespace mysqlx {
@@ -45,7 +48,7 @@ using namespace drv;
 static zend_class_entry* collection_remove_class_entry;
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_collection__remove__sort, 0, ZEND_RETURN_VALUE, 1)
-	ZEND_ARG_INFO(no_pass_by_ref, sort_expr)
+	ZEND_ARG_INFO(no_pass_by_ref, sort_expressions)
 ZEND_END_ARG_INFO()
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_collection__remove__limit, 0, ZEND_RETURN_VALUE, 1)
@@ -63,27 +66,21 @@ ZEND_END_ARG_INFO()
 
 //------------------------------------------------------------------------------
 
-
-/* {{{ Collection_remove::init() */
 bool Collection_remove::init(
-	zval* obj_zv,
 	xmysqlnd_collection* coll,
 	const util::string_view& search_expression)
 {
-	if (!obj_zv || !coll || search_expression.empty()) return false;
-	object_zv = obj_zv;
+	if (!coll || search_expression.empty()) return false;
 	collection = coll->get_reference();
 	remove_op = xmysqlnd_crud_collection_remove__create(
 		mnd_str2c(collection->get_schema()->get_name()),
 		mnd_str2c(collection->get_name()));
 	if (!remove_op) return false;
 
-	return xmysqlnd_crud_collection_remove__set_criteria(remove_op, search_expression.to_std_string()) == PASS;
+	return xmysqlnd_crud_collection_remove__set_criteria(
+		remove_op, search_expression.to_std_string()) == PASS;
 }
-/* }}} */
 
-
-/* {{{ Collection_remove::~Collection_remove() */
 Collection_remove::~Collection_remove()
 {
 	if (remove_op) {
@@ -94,121 +91,92 @@ Collection_remove::~Collection_remove()
 		xmysqlnd_collection_free(collection, nullptr, nullptr);
 	}
 }
-/* }}} */
 
-
-/* {{{ proto mixed Collection_remove::sort() */
-void Collection_remove::sort(
-	zval* sort_expr,
-	int num_of_expr,
-	zval* return_value)
+bool Collection_remove::sort(
+	zval* sort_expressions,
+	int num_of_expr)
 {
 	DBG_ENTER("Collection_remove::sort");
 
-	RETVAL_FALSE;
-
-	if (!sort_expr) {
-		DBG_VOID_RETURN;
+	if (!sort_expressions) {
+		DBG_RETURN(false);
 	}
 
 	for( int i{0}; i < num_of_expr ; ++i ) {
-		switch (Z_TYPE(sort_expr[i])) {
-		case IS_STRING:
+		const util::zvalue sort_expr(sort_expressions[i]);
+		switch (sort_expr.type()) {
+		case util::zvalue::Type::String:
 			{
-				const MYSQLND_CSTRING sort_expr_str = { Z_STRVAL(sort_expr[i]),
-											Z_STRLEN(sort_expr[i]) };
-				if (PASS == xmysqlnd_crud_collection_remove__add_sort(remove_op,
+				const MYSQLND_CSTRING sort_expr_str{ sort_expr.c_str(), sort_expr.length() };
+				if (FAIL == xmysqlnd_crud_collection_remove__add_sort(remove_op,
 													sort_expr_str)) {
-					ZVAL_COPY(return_value, object_zv);
+					DBG_RETURN(false);
 				}
 			}
 			break;
-		case IS_ARRAY:
+		case util::zvalue::Type::Array:
 			{
-				zval* entry{nullptr};
-				MYSQLX_HASH_FOREACH_VAL(Z_ARRVAL(sort_expr[i]), entry) {
-					const MYSQLND_CSTRING sort_expr_str = { Z_STRVAL_P(entry),
-												Z_STRLEN_P(entry) };
-					if (Z_TYPE_P(entry) != IS_STRING) {
+				for (auto it{ sort_expr.vbegin() }; it != sort_expr.vend(); ++it) {
+					const util::zvalue& sort_expr_entry(*it);
+					if (!sort_expr_entry.is_string()) {
 						RAISE_EXCEPTION(err_msg_wrong_param_1);
-						DBG_VOID_RETURN;
+						DBG_RETURN(false);
 					}
+					const MYSQLND_CSTRING sort_expr_str{
+						sort_expr_entry.c_str(), sort_expr_entry.length() };
 					if (FAIL == xmysqlnd_crud_collection_remove__add_sort(remove_op,
 															sort_expr_str)) {
 						RAISE_EXCEPTION(err_msg_add_sort_fail);
-						DBG_VOID_RETURN;
+						DBG_RETURN(false);
 					}
-				} ZEND_HASH_FOREACH_END();
-				ZVAL_COPY(return_value, object_zv);
+				}
 			}
 			break;
 		default:
 			RAISE_EXCEPTION(err_msg_wrong_param_3);
+			DBG_RETURN(false);
 		}
 	}
-	DBG_VOID_RETURN;
+	DBG_RETURN(true);
 }
-/* }}} */
 
-
-/* {{{ proto mixed Collection_remove::limit() */
-void Collection_remove::limit(
-	zend_long rows,
-	zval* return_value)
+bool Collection_remove::limit(zend_long rows)
 {
-
 	DBG_ENTER("Collection_remove::limit");
 
 	if (rows < 0) {
 		RAISE_EXCEPTION(err_msg_wrong_param_2);
-		DBG_VOID_RETURN;
+		DBG_RETURN(false);
 	}
 
-	RETVAL_FALSE;
-
-	if (PASS == xmysqlnd_crud_collection_remove__set_limit(remove_op, rows)) {
-		ZVAL_COPY(return_value, object_zv);
-	}
-
-	DBG_VOID_RETURN;
+	DBG_RETURN(PASS == xmysqlnd_crud_collection_remove__set_limit(remove_op, rows));
 }
-/* }}} */
 
-
-/* {{{ proto mixed Collection_remove::bind() */
-void Collection_remove::bind(
-	HashTable* bind_variables,
-	zval* return_value)
+bool Collection_remove::bind(const util::zvalue& bind_variables)
 {
 	DBG_ENTER("Collection_remove::bind");
 
-	RETVAL_FALSE;
-
-	zend_string* key{nullptr};
-	zval* val{nullptr};
-	MYSQLX_HASH_FOREACH_STR_KEY_VAL(bind_variables, key, val) {
-		if (key) {
-			const MYSQLND_CSTRING variable = { ZSTR_VAL(key), ZSTR_LEN(key) };
-			if (FAIL == xmysqlnd_crud_collection_remove__bind_value(remove_op, variable, val)) {
-				RAISE_EXCEPTION(err_msg_bind_fail);
-				DBG_VOID_RETURN;
-			}
+	for (const auto& variable_value : bind_variables) {
+		const util::zvalue& var_name{ variable_value.first };
+		if (!var_name.is_string()) {
+			RAISE_EXCEPTION(err_msg_bind_fail);
+			DBG_RETURN(false);
 		}
-	} ZEND_HASH_FOREACH_END();
-	ZVAL_COPY(return_value, object_zv);
+		const util::zvalue& var_value{ variable_value.second };
+		if (FAIL == xmysqlnd_crud_collection_remove__bind_value(
+			remove_op, var_name.to_string(), var_value.ptr())) {
+			RAISE_EXCEPTION(err_msg_bind_fail);
+			DBG_RETURN(false);
+		}
+	}
 
-	DBG_VOID_RETURN;
+	DBG_RETURN(true);
 }
-/* }}} */
 
-
-/* {{{ proto mixed Collection_remove::execute() */
-void Collection_remove::execute(zval* return_value)
+void Collection_remove::execute(zval* resultset)
 {
 	DBG_ENTER("Collection_remove::execute");
 
-	RETVAL_FALSE;
-
 	DBG_INF_FMT("remove_op=%p collection=%p", remove_op, collection);
 	if (remove_op && collection) {
 		if (FALSE == xmysqlnd_crud_collection_remove__is_initialized(remove_op)) {
@@ -217,70 +185,56 @@ void Collection_remove::execute(zval* return_value)
 			static const MYSQLND_CSTRING errmsg = { "Remove not completely initialized", sizeof("Remove not completely initialized") - 1 };
 			mysqlx_new_exception(errcode, sqlstate, errmsg);
 		} else {
-			xmysqlnd_stmt* stmt = collection->remove(remove_op);
+			xmysqlnd_stmt* stmt{ collection->remove(remove_op) };
 			if (stmt) {
-				zval stmt_zv;
-				ZVAL_UNDEF(&stmt_zv);
-				mysqlx_new_stmt(&stmt_zv, stmt);
-				if (Z_TYPE(stmt_zv) == IS_NULL) {
+				util::zvalue stmt_zv;
+				mysqlx_new_stmt(stmt_zv.ptr(), stmt);
+				if (stmt_zv.is_null()) {
 					xmysqlnd_stmt_free(stmt, nullptr, nullptr);
-				}
-				if (Z_TYPE(stmt_zv) == IS_OBJECT) {
-					zval zv;
-					ZVAL_UNDEF(&zv);
+				} else if (stmt_zv.is_object()) {
 					zend_long flags{0};
-					mysqlx_statement_execute_read_response(Z_MYSQLX_P(&stmt_zv), flags, MYSQLX_RESULT, &zv);
-
-					ZVAL_COPY(return_value, &zv);
-					zval_dtor(&zv);
+					mysqlx_statement_execute_read_response(
+						Z_MYSQLX_P(stmt_zv.ptr()), flags, MYSQLX_RESULT, resultset);
 				}
-				zval_ptr_dtor(&stmt_zv);
 			}
 		}
 	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
-
 
 //------------------------------------------------------------------------------
 
 
-/* {{{ mysqlx_collection__remove::__construct */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__remove, __construct)
 {
 	UNUSED_INTERNAL_FUNCTION_PARAMETERS();
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__remove::sort() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__remove, sort)
 {
 	DBG_ENTER("mysqlx_collection__remove::sort");
 
 	zval* object_zv{nullptr};
-	zval* sort_expr{nullptr};
+	zval* sort_expressions{nullptr};
 	int num_of_expr{0};
 	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "O+",
 									&object_zv,
 									collection_remove_class_entry,
-									&sort_expr,
+									&sort_expressions,
 									&num_of_expr))
 	{
 		DBG_VOID_RETURN;
 	}
 
 	Collection_remove& coll_remove = util::fetch_data_object<Collection_remove>(object_zv);
-	coll_remove.sort(sort_expr, num_of_expr, return_value);
+	if (coll_remove.sort(sort_expressions, num_of_expr)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__remove::limit() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__remove, limit)
 {
 	DBG_ENTER("mysqlx_collection__remove::limit");
@@ -300,36 +254,35 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__remove, limit)
 	}
 
 	Collection_remove& coll_remove = util::fetch_data_object<Collection_remove>(object_zv);
-	coll_remove.limit(rows, return_value);
+	if (coll_remove.limit(rows)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__remove::bind() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__remove, bind)
 {
 	DBG_ENTER("mysqlx_collection__remove::bind");
 
 	zval* object_zv{nullptr};
-	HashTable* bind_variables{nullptr};
-	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Oh",
+	zval* bind_vars{nullptr};
+	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Oz",
 												&object_zv, collection_remove_class_entry,
-												&bind_variables))
+												&bind_vars))
 	{
 		DBG_VOID_RETURN;
 	}
 
 	Collection_remove& coll_remove = util::fetch_data_object<Collection_remove>(object_zv);
-	coll_remove.bind(bind_variables, return_value);
+	util::zvalue bind_variables(bind_vars);
+	if (coll_remove.bind(bind_variables)) {
+		util::zvalue::copy_to(object_zv, return_value);
+	}
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ proto mixed mysqlx_collection__remove::execute() */
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__remove, execute)
 {
 	DBG_ENTER("mysqlx_collection__remove::execute");
@@ -346,10 +299,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_collection__remove, execute)
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ mysqlx_collection__remove_methods[] */
 static const zend_function_entry mysqlx_collection__remove_methods[] = {
 	PHP_ME(mysqlx_collection__remove, __construct,	nullptr,											ZEND_ACC_PRIVATE)
 
@@ -360,8 +310,6 @@ static const zend_function_entry mysqlx_collection__remove_methods[] = {
 
 	{nullptr, nullptr, nullptr}
 };
-/* }}} */
-
 
 static zend_object_handlers collection_remove_handlers;
 static HashTable collection_remove_properties;
@@ -371,16 +319,12 @@ const st_mysqlx_property_entry collection_remove_property_entries[] =
 	{{nullptr,	0}, nullptr, nullptr}
 };
 
-/* {{{ mysqlx_collection__remove_free_storage */
 static void
 mysqlx_collection__remove_free_storage(zend_object* object)
 {
 	util::free_object<Collection_remove>(object);
 }
-/* }}} */
 
-
-/* {{{ php_mysqlx_collection__remove_object_allocator */
 static zend_object *
 php_mysqlx_collection__remove_object_allocator(zend_class_entry* class_type)
 {
@@ -391,10 +335,7 @@ php_mysqlx_collection__remove_object_allocator(zend_class_entry* class_type)
 		&collection_remove_properties);
 	DBG_RETURN(&mysqlx_object->zo);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_register_collection__remove_class */
 void
 mysqlx_register_collection__remove_class(UNUSED_INIT_FUNC_ARGS, zend_object_handlers* mysqlx_std_object_handlers)
 {
@@ -413,19 +354,13 @@ mysqlx_register_collection__remove_class(UNUSED_INIT_FUNC_ARGS, zend_object_hand
 		mysqlx_crud_operation_limitable_interface_entry,
 		mysqlx_crud_operation_sortable_interface_entry);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_unregister_collection__remove_class */
 void
 mysqlx_unregister_collection__remove_class(UNUSED_SHUTDOWN_FUNC_ARGS)
 {
 	zend_hash_destroy(&collection_remove_properties);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_new_collection__remove */
 void
 mysqlx_new_collection__remove(
 	zval* return_value,
@@ -437,7 +372,7 @@ mysqlx_new_collection__remove(
 		const st_mysqlx_object* const mysqlx_object = Z_MYSQLX_P(return_value);
 		Collection_remove* const coll_remove = static_cast<Collection_remove*>(mysqlx_object->ptr);
 		if (!coll_remove ||
-			!coll_remove->init(return_value, collection->get_reference(), search_expression))
+			!coll_remove->init(collection->get_reference(), search_expression))
 		{
 			DBG_ERR("Error");
 			php_error_docref(nullptr, E_WARNING, "invalid object of class %s", ZSTR_VAL(mysqlx_object->zo.ce->name));
@@ -447,17 +382,7 @@ mysqlx_new_collection__remove(
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
 } // namespace devapi
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
