@@ -13,6 +13,8 @@
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Andrey Hristov <andrey@php.net>                             |
+  |          Filip Janiszewski <fjanisze@php.net>                        |
+  |          Darek Slusarczyk <marines@php.net>                          |
   +----------------------------------------------------------------------+
 */
 #ifndef MYSQLX_COLLECTION__REMOVE_H
@@ -20,6 +22,8 @@
 
 namespace mysqlx {
 
+namespace util { class zvalue; }
+
 namespace drv {
 
 struct xmysqlnd_collection;
@@ -29,41 +33,31 @@ struct st_xmysqlnd_crud_collection_op__remove;
 
 namespace devapi {
 
-/* {{{ Collection_remove */
 class Collection_remove : public util::custom_allocable
 {
 public:
 	Collection_remove() = default;
-	Collection_remove(const Collection_remove& rhs) = delete;
-	Collection_remove& operator=(const Collection_remove& rhs) = delete;
+	Collection_remove(const Collection_remove&) = delete;
+	Collection_remove& operator=(const Collection_remove&) = delete;
 	~Collection_remove();
 
 	bool init(
-		zval* object_zv,
 		drv::xmysqlnd_collection* collection,
 		const util::string_view& search_expression);
 
 public:
-	void sort(
-		zval* sort_expr,
-		int num_of_expr,
-		zval* return_value);
-	void limit(
-		zend_long rows,
-		zval* return_value);
-	void bind(
-		HashTable* bind_variables,
-		zval* return_value);
+	bool sort(
+		zval* sort_expressions,
+		int num_of_expr);
+	bool limit(zend_long rows);
+	bool bind(const util::zvalue& bind_variables);
 	void execute(zval* return_value);
 
 private:
-	zval* object_zv{nullptr};
 	drv::xmysqlnd_collection* collection{nullptr};
 	drv::st_xmysqlnd_crud_collection_op__remove* remove_op{nullptr};
 
 };
-/* }}} */
-
 
 void mysqlx_new_collection__remove(
 	zval* return_value,
@@ -77,12 +71,3 @@ void mysqlx_unregister_collection__remove_class(SHUTDOWN_FUNC_ARGS);
 } // namespace mysqlx
 
 #endif /* MYSQLX_COLLECTION__REMOVE_H */
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
