@@ -28,19 +28,15 @@ namespace devapi {
 zend_class_entry * mysqlx_crud_operation_sortable_interface_entry;
 
 ZEND_BEGIN_ARG_INFO_EX(mysqlx_crud_operation_sortable__sort, 0, ZEND_RETURN_VALUE, 1)
-	ZEND_ARG_INFO(no_pass_by_ref, sort_expr)
+	ZEND_ARG_INFO(no_pass_by_ref, sort_expressions)
 ZEND_END_ARG_INFO()
 
 
-/* {{{ mysqlx_crud_operation_sortable_methods[] */
 static const zend_function_entry mysqlx_crud_operation_sortable_methods[] = {
 	PHP_ABSTRACT_ME(mysqlx_crud_operation_sortable, sort, mysqlx_crud_operation_sortable__sort)
 	{nullptr, nullptr, nullptr}
 };
-/* }}} */
 
-
-/* {{{ mysqlx_register_crud_operation_sortable_interface */
 void
 mysqlx_register_crud_operation_sortable_interface(UNUSED_INIT_FUNC_ARGS, zend_object_handlers* /*mysqlx_std_object_handlers*/)
 {
@@ -48,26 +44,12 @@ mysqlx_register_crud_operation_sortable_interface(UNUSED_INIT_FUNC_ARGS, zend_ob
 	INIT_NS_CLASS_ENTRY(tmp_ce, "mysql_xdevapi", "CrudOperationSortable", mysqlx_crud_operation_sortable_methods);
 	mysqlx_crud_operation_sortable_interface_entry = zend_register_internal_interface(&tmp_ce);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_unregister_crud_operation_sortable_interface */
 void
 mysqlx_unregister_crud_operation_sortable_interface(UNUSED_SHUTDOWN_FUNC_ARGS)
 {
 }
-/* }}} */
 
 } // namespace devapi
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
-
