@@ -19,9 +19,7 @@
 extern "C" {
 #include <zend_exceptions.h>
 #include "mysqlnd_api.h"
-#ifdef HAVE_SPL
 #include <ext/spl/spl_exceptions.h> /* spl_ce_RuntimeException */
-#endif
 }
 #include "xmysqlnd/xmysqlnd.h"
 #include "php_mysqlx.h"
@@ -61,14 +59,10 @@ RAISE_EXCEPTION(const int errcode, const char * const msg)
 	} \
 }
 
-/* {{{ mysqlx_exception_methods[] */
 static const zend_function_entry mysqlx_exception_methods[] = {
 	{nullptr, nullptr, nullptr}
 };
-/* }}} */
 
-
-/* {{{ mysqlx_exception_property__message */
 static zval *
 mysqlx_exception_property__message(const st_mysqlx_object* obj, zval * return_value)
 {
@@ -88,10 +82,7 @@ mysqlx_exception_property__message(const st_mysqlx_object* obj, zval * return_va
 	}
 	DBG_RETURN(return_value);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_exception_property__level */
 static zval *
 mysqlx_exception_property__level(const st_mysqlx_object* obj, zval * return_value)
 {
@@ -100,10 +91,7 @@ mysqlx_exception_property__level(const st_mysqlx_object* obj, zval * return_valu
 	ZVAL_LONG(return_value, object->level);
 	DBG_RETURN(return_value);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_exception_property__code */
 static zval *
 mysqlx_exception_property__code(const st_mysqlx_object* obj, zval * return_value)
 {
@@ -113,10 +101,7 @@ mysqlx_exception_property__code(const st_mysqlx_object* obj, zval * return_value
 	ZVAL_LONG(return_value, object->code);
 	DBG_RETURN(return_value);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_column_meta_property_entries[] */
 static const struct st_mysqlx_property_entry mysqlx_exception_property_entries[] =
 {
 	{{"message",			sizeof("message") - 1},		mysqlx_exception_property__message,	nullptr},
@@ -124,14 +109,11 @@ static const struct st_mysqlx_property_entry mysqlx_exception_property_entries[]
 	{{"code",				sizeof("code") - 1},		mysqlx_exception_property__code,		nullptr},
 	{{nullptr, 				0},							nullptr, 								nullptr}
 };
-/* }}} */
-
 
 static zend_object_handlers mysqlx_object_exception_handlers;
 static HashTable mysqlx_exception_properties;
 
 
-/* {{{ mysqlx_register_exception_class */
 void
 mysqlx_register_exception_class(UNUSED_INIT_FUNC_ARGS, zend_object_handlers * mysqlx_std_object_handlers)
 {
@@ -140,30 +122,20 @@ mysqlx_register_exception_class(UNUSED_INIT_FUNC_ARGS, zend_object_handlers * my
 	{
 		zend_class_entry tmp_ce;
 		INIT_NS_CLASS_ENTRY(tmp_ce, "mysql_xdevapi", "Exception", mysqlx_exception_methods);
-#ifdef HAVE_SPL
 		mysqlx_exception_class_entry = zend_register_internal_class_ex(&tmp_ce, spl_ce_RuntimeException);
-#else
-		mysqlx_exception_class_entry = zend_register_internal_class_ex(&tmp_ce, zend_ce_exception);
-#endif
 	}
 
 	zend_hash_init(&mysqlx_exception_properties, 0, nullptr, mysqlx_free_property_cb, 1);
 
 	mysqlx_add_properties(&mysqlx_exception_properties, mysqlx_exception_property_entries);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_unregister_exception_class */
 void
 mysqlx_unregister_exception_class(UNUSED_SHUTDOWN_FUNC_ARGS)
 {
 	zend_hash_destroy(&mysqlx_exception_properties);
 }
-/* }}} */
 
-
-/* {{{ mysqlx_new_exception */
 void
 mysqlx_new_exception(const unsigned int code, const MYSQLND_CSTRING sql_state, const MYSQLND_CSTRING message)
 {
@@ -176,10 +148,7 @@ mysqlx_new_exception(const unsigned int code, const MYSQLND_CSTRING sql_state, c
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ mysqlx_new_exception_ex */
 void
 mysqlx_new_exception_ex(const unsigned int code, const MYSQLND_CSTRING /*sql_state*/, const char * const format, ...)
 {
@@ -195,17 +164,7 @@ mysqlx_new_exception_ex(const unsigned int code, const MYSQLND_CSTRING /*sql_sta
 	mnd_efree(msg);
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
 } // namespace devapi
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
