@@ -39,17 +39,10 @@ void mysqlx_new_session(zval* return_value, drv::XMYSQLND_SESSION session);
 void mysqlx_register_session_class(INIT_FUNC_ARGS, zend_object_handlers * mysqlx_std_object_handlers);
 void mysqlx_unregister_session_class(SHUTDOWN_FUNC_ARGS);
 
+PHP_FUNCTION(mysql_xdevapi_getSession);
+
 } // namespace devapi
 
 } // namespace mysqlx
 
 #endif /* MYSQLX_SESSION_H */
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
