@@ -18,6 +18,10 @@
 #ifndef MYSQL_XDEVAPI_PHP_API_H
 #define MYSQL_XDEVAPI_PHP_API_H
 
+#ifndef __STDC_FORMAT_MACROS
+#define __STDC_FORMAT_MACROS 1
+#endif
+
 #ifdef PHP_WIN32
 #pragma warning( push )
 #pragma warning( disable : 4018 4244 4706)
@@ -32,13 +36,15 @@ extern "C" {
 #undef max
 }
 
+#include <inttypes.h>
+#define MYSQLX_LLU_SPEC "%" PRIu64
+
 #ifdef PHP_WIN32
 #pragma warning( pop )
 #endif // PHP_WIN32
 
 #include "util/compiler_utils.h"
 
-
 #ifdef PHP_WIN32
 
 #define MYSQLX_HASH_FOREACH_VAL(ht, _val) \
@@ -56,7 +62,7 @@ extern "C" {
 	ZEND_HASH_FOREACH_STR_KEY_VAL(ht, _key, _val) \
 	MYSQLX_RESTORE_WARNINGS()
 
-#else
+#else // UNIX OSes
 
 #define MYSQLX_HASH_FOREACH_VAL ZEND_HASH_FOREACH_VAL
 #define MYSQLX_HASH_FOREACH_PTR	ZEND_HASH_FOREACH_PTR
@@ -64,14 +70,4 @@ extern "C" {
 
 #endif
 
-
 #endif // MYSQL_XDEVAPI_PHP_API_H
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
