@@ -32,7 +32,6 @@
 #include "mysqlx_exception.h"
 #include "mysqlx_execution_status.h"
 #include "mysqlx_expression.h"
-#include "mysqlx_x_session.h"
 #include "mysqlx_schema.h"
 #include "mysqlx_collection.h"
 #include "mysqlx_collection__add.h"
@@ -55,32 +54,12 @@
 #include "mysqlx_object.h"
 #include "mysqlx_warning.h"
 
-#include "messages/mysqlx_connection.h"
-#include "messages/mysqlx_pfc.h"
-
-#include "messages/mysqlx_resultset__column_metadata.h"
-#include "messages/mysqlx_resultset__resultset_metadata.h"
-#include "messages/mysqlx_resultset__data_row.h"
-
-#include "messages/mysqlx_message__ok.h"
-#include "messages/mysqlx_message__error.h"
-#include "messages/mysqlx_message__auth_start.h"
-#include "messages/mysqlx_message__auth_ok.h"
-#include "messages/mysqlx_message__capabilities_get.h"
-#include "messages/mysqlx_message__capabilities_set.h"
-#include "messages/mysqlx_message__capability.h"
-#include "messages/mysqlx_message__capabilities.h"
-#include "messages/mysqlx_message__stmt_execute.h"
-#include "messages/mysqlx_message__stmt_execute_ok.h"
-#include "messages/mysqlx_message__data_fetch_done.h"
-
 namespace mysqlx {
 
 namespace devapi {
 
 using namespace drv;
 
-/* {{{ mysqlx_minit_classes */
 PHP_MYSQL_XDEVAPI_API int
 mysqlx_minit_classes(INIT_FUNC_ARGS)
 {
@@ -109,7 +88,6 @@ mysqlx_minit_classes(INIT_FUNC_ARGS)
 	mysqlx_register_execution_status_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
 	mysqlx_register_expression_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
 
-	mysqlx_register_x_session_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
 	mysqlx_register_session_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
 	mysqlx_register_client_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
 
@@ -137,30 +115,6 @@ mysqlx_minit_classes(INIT_FUNC_ARGS)
 	mysqlx_register_table__select_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
 	mysqlx_register_table__update_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
 
-
-	using namespace msg;
-
-	mysqlx_register_connection_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-
-	mysqlx_register_pfc_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_message__ok_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_message__error_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_message__capability_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_message__capabilities_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_message__capabilities_get_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_message__capabilities_set_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-
-	mysqlx_register_message__auth_start_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_message__auth_ok_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-
-	mysqlx_register_message__stmt_execute_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_message__stmt_execute_ok_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-
-	mysqlx_register_column_metadata_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_resultset_metadata_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_data_row_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-	mysqlx_register_message__data_fetch_done_class(INIT_FUNC_ARGS_PASSTHRU, &mysqlx_std_object_handlers);
-
 	// extension consts
 	REGISTER_STRING_CONSTANT("MYSQLX_VERSION", const_cast<char*>(PHP_MYSQL_XDEVAPI_VERSION), CONST_CS | CONST_PERSISTENT);
 	REGISTER_LONG_CONSTANT("MYSQLX_VERSION_ID", MYSQL_XDEVAPI_VERSION_ID, CONST_CS | CONST_PERSISTENT);
@@ -211,35 +165,10 @@ mysqlx_minit_classes(INIT_FUNC_ARGS)
 
 	return SUCCESS;
 }
-/* }}} */
 
-
-/* {{{ mysqlx_mshutdown_classes */
 PHP_MYSQL_XDEVAPI_API int
 mysqlx_mshutdown_classes(SHUTDOWN_FUNC_ARGS)
 {
-	using namespace msg;
-
-	mysqlx_unregister_message__data_fetch_done_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_data_row_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_resultset_metadata_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_column_metadata_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-
-	mysqlx_unregister_message__stmt_execute_ok_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_message__stmt_execute_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-
-	mysqlx_unregister_message__auth_ok_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_message__auth_start_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-
-	mysqlx_unregister_message__capabilities_set_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_message__capabilities_get_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_message__capabilities_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_message__capability_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_message__error_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_message__ok_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_pfc_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_connection_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-
 	mysqlx_unregister_table__update_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
 	mysqlx_unregister_table__select_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
 	mysqlx_unregister_table__insert_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
@@ -264,7 +193,6 @@ mysqlx_mshutdown_classes(SHUTDOWN_FUNC_ARGS)
 
 	mysqlx_unregister_client_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
 	mysqlx_unregister_session_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
-	mysqlx_unregister_x_session_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
 
 	mysqlx_unregister_expression_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
 	mysqlx_unregister_execution_status_class(SHUTDOWN_FUNC_ARGS_PASSTHRU);
@@ -283,18 +211,7 @@ mysqlx_mshutdown_classes(SHUTDOWN_FUNC_ARGS)
 	UNREGISTER_INI_ENTRIES();
 	return SUCCESS;
 }
-/* }}} */
 
 } // namespace devapi
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
-
