@@ -23,6 +23,7 @@ extern "C" {
 #include "exceptions.h"
 #include "mysqlx_exception.h"
 #include "types.h"
+#include "string_utils.h"
 
 namespace mysqlx {
 
@@ -34,8 +35,7 @@ namespace
 const char* const General_sql_state{ GENERAL_SQL_STATE };
 const char* const Unknown_error_message{ "Unknown error" };
 
-/* {{{ mysqlx::util::code_to_err_msg */
-const std::map<xdevapi_exception::Code, const char* const> code_to_err_msg = {
+const std::map<xdevapi_exception::Code, const char* const> code_to_err_msg{
 	{ xdevapi_exception::Code::fetch_fail, "Couldn't fetch data" },
 	{ xdevapi_exception::Code::meta_fail, "Unable to extract metadata" },
 	{ xdevapi_exception::Code::add_doc, "Error adding document" },
@@ -104,97 +104,111 @@ const std::map<xdevapi_exception::Code, const char* const> code_to_err_msg = {
 	{ xdevapi_exception::Code::conn_attrib_wrong_type,
 		"The value of \"connection-attributes\" must be either a boolean or a list of key-value pairs"},
 	{ xdevapi_exception::Code::conn_attrib_dup_key,
-		"Duplicate key used in the \"connection-attributes\" option." }
+		"Duplicate key used in the \"connection-attributes\" option." },
+	{ xdevapi_exception::Code::unknown_client_conn_option,
+		"Unknown client connection option in Uri:" },
+	{ xdevapi_exception::Code::unknown_ssl_mode, "Unknown SSL mode:" },
+	{ xdevapi_exception::Code::unknown_tls_version, "Unknown TLS version:" },
+	{ xdevapi_exception::Code::openssl_unavailable,
+		"trying to setup secure connection while OpenSSL is not available" },
+	{ xdevapi_exception::Code::empty_tls_versions,
+		"at least one TLS protocol version must be specified in tls-versions list" },
+	{ xdevapi_exception::Code::cannot_connect_by_ssl, "Cannot connect to MySQL by using SSL" },
+	{ xdevapi_exception::Code::cannot_setup_tls,
+		"Negative response from the server, not able to setup TLS." },
+	{ xdevapi_exception::Code::no_valid_cipher_in_list,
+		"No valid cipher found in the ssl ciphers list."},
+	{ xdevapi_exception::Code::no_valid_ciphersuite_in_list,
+		"No valid cipher suite found in the tls ciphersuites list."},
 };
-/* }}} */
 
-/* {{{ to_sql_state */
-string to_sql_state(const char* sql_state)
+string to_sql_state(const string& sql_state)
 {
-	return sql_state ? sql_state : General_sql_state;
+	return sql_state.empty() ? General_sql_state : sql_state;
 }
-/* }}} */
 
-/* {{{ to_error_msg */
-string to_error_msg(unsigned int code, const char* what)
+string to_error_msg(xdevapi_exception::Code code, const string& what)
 {
-	if (what) return what;
+	string msg;
+	auto it{ code_to_err_msg.find(code) };
+	if (it != code_to_err_msg.end()) {
+		msg = it->second;
+	}
 
-	auto it{ code_to_err_msg.find(static_cast<xdevapi_exception::Code>(code)) };
-	if (it != code_to_err_msg.end()) return it->second;
+	if (!what.empty()) {
+		if (!msg.empty()) msg += ' ';
+		msg += what;
+	}
 
-	return Unknown_error_message;
+	return msg.empty() ? Unknown_error_message : msg;
+}
+
+string to_error_msg(unsigned int code, const string& what)
+{
+	return to_error_msg(static_cast<xdevapi_exception::Code>(code), what);
 }
-/* }}} */
 
 } // anonymous namespace
 
 //------------------------------------------------------------------------------
 
-/* {{{ mysqlx::util::xdevapi_exception::xdevapi_exception */
 xdevapi_exception::xdevapi_exception(Code code)
-	: xdevapi_exception(code, code_to_err_msg.at(code))
+	: xdevapi_exception(code, nullptr)
 {
 }
-/* }}} */
 
-/* {{{ mysqlx::util::xdevapi_exception::xdevapi_exception */
 xdevapi_exception::xdevapi_exception(Code code, const string& msg)
 	: xdevapi_exception(static_cast<unsigned int>(code), msg)
 {
 }
-/* }}} */
 
-/* {{{ mysqlx::util::xdevapi_exception::xdevapi_exception */
+xdevapi_exception::xdevapi_exception(Code code, const char* msg)
+	: xdevapi_exception(static_cast<unsigned int>(code), General_sql_state, msg)
+{
+}
+
+xdevapi_exception::xdevapi_exception(Code code, const std::string& msg)
+	: xdevapi_exception(code, util::to_string(msg))
+{
+}
+
 xdevapi_exception::xdevapi_exception(unsigned int code, const string& msg)
 	: xdevapi_exception(code, General_sql_state, msg)
 {
 }
-/* }}} */
 
-/* {{{ mysqlx::util::xdevapi_exception::xdevapi_exception */
 xdevapi_exception::xdevapi_exception(unsigned int code, const char* sql_state, const char* msg)
-	: xdevapi_exception(code, to_sql_state(sql_state), to_error_msg(code, msg))
+	: xdevapi_exception(code, to_string(sql_state), to_string(msg))
 {
 }
-/* }}} */
 
-/* {{{ mysqlx::util::xdevapi_exception::xdevapi_exception */
 xdevapi_exception::xdevapi_exception(unsigned int code, const string& sql_state, const string& msg)
 	: std::runtime_error(prepare_reason_msg(code, sql_state, msg).c_str())
 	, code(code)
 {
 }
-/* }}} */
 
 //------------------------------------------------------------------------------
 
-/* {{{ mysqlx::util::doc_ref_exception::doc_ref_exception */
 doc_ref_exception::doc_ref_exception(Severity severity, _zend_class_entry* ce)
 	: doc_ref_exception(severity, util::string("invalid object of class ") + ZSTR_VAL(ce->name))
 {
 }
-/* }}} */
 
-/* {{{ mysqlx::util::doc_ref_exception::doc_ref_exception */
 doc_ref_exception::doc_ref_exception(Severity severity, const string& msg)
 	: std::runtime_error(msg.c_str())
 	, severity(severity)
 {
 }
-/* }}} */
 
 //------------------------------------------------------------------------------
 
-/* {{{ mysqlx::util::raise_xdevapi_exception */
 void raise_xdevapi_exception(const xdevapi_exception& e)
 {
 	const char* what = e.what();
 	zend_throw_exception(devapi::mysqlx_exception_class_entry, what, e.code);
 }
-/* }}} */
 
-/* {{{ mysqlx::util::raise_doc_ref_exception */
 void raise_doc_ref_exception(const doc_ref_exception& e)
 {
 	static const std::map<doc_ref_exception::Severity, int> severity_mapping = {
@@ -205,61 +219,48 @@ void raise_doc_ref_exception(const doc_ref_exception& e)
 	const char* what = e.what();
 	php_error_docref(nullptr, severity, "%s", what);
 }
-/* }}} */
 
-/* {{{ mysqlx::util::raise_common_exception */
 void raise_common_exception(const std::exception& e)
 {
 	const char* what = e.what();
 	const int CommonExceptionCode = 0; //TODO
 	zend_throw_exception(devapi::mysqlx_exception_class_entry, what, CommonExceptionCode);
 }
-/* }}} */
 
-/* {{{ mysqlx::util::raise_unknown_exception */
 void raise_unknown_exception()
 {
 	const char* what = "MySQL XDevAPI - unknown exception";
 	const int UnknownExceptionCode = 0; //TODO
 	zend_throw_exception(devapi::mysqlx_exception_class_entry, what, UnknownExceptionCode);
 }
-/* }}} */
 
 //------------------------------------------------------------------------------
 
-/* {{{ mysqlx::util::prepare_reason_msg */
 string prepare_reason_msg(unsigned int code, const string& sql_state, const string& what)
 {
 	ostringstream os;
-	os << '[' << code << "][" << sql_state << "] " << what;
+	os << '[' << code << "][" << to_sql_state(sql_state) << "] " << to_error_msg(code, what);
 	const string& reason = os.str();
 	return reason;
 }
-/* }}} */
 
-/* {{{ mysqlx::util::prepare_reason_msg */
 string prepare_reason_msg(unsigned int code, const char* sql_state, const char* what)
 {
-	return prepare_reason_msg(code, to_sql_state(sql_state), to_error_msg(code, what));
+	return prepare_reason_msg(code, to_string(sql_state), to_string(what));
 }
-/* }}} */
 
-/* {{{ mysqlx::util::log_warning */
 void log_warning(const string& msg)
 {
 	php_error_docref(nullptr, E_WARNING, "%s", msg.c_str());
 }
-/* }}} */
+
+void set_error_info(util::xdevapi_exception::Code code, MYSQLND_ERROR_INFO* error_info)
+{
+	error_info->error_no = static_cast<unsigned int>(code);
+	strcpy(error_info->sqlstate, General_sql_state);
+	error_info->error[0] = 0;
+}
 
 } // namespace util
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
