@@ -23,13 +23,13 @@
 
 extern "C" {
 struct _zend_class_entry;
+struct st_mysqlnd_error_info;
 }
 
 namespace mysqlx {
 
 namespace util {
 
-/* {{{ mysqlx::util::xdevapi_exception */
 struct xdevapi_exception : public std::runtime_error
 {
 	enum class Code : unsigned int
@@ -96,20 +96,30 @@ struct xdevapi_exception : public std::runtime_error
 		ps_limit_not_supported,
 		session_reset_failure,
 		conn_attrib_wrong_type,
-		conn_attrib_dup_key
+		conn_attrib_dup_key,
+		unknown_client_conn_option,
+		unknown_ssl_mode,
+		unknown_tls_version,
+		openssl_unavailable,
+		empty_tls_versions,
+		cannot_connect_by_ssl,
+		cannot_setup_tls,
+		no_valid_cipher_in_list,
+		no_valid_ciphersuite_in_list,
+		out_of_range,
 	};
 
 	xdevapi_exception(Code code);
 	xdevapi_exception(Code code, const string& msg);
+	xdevapi_exception(Code code, const char* msg);
+	xdevapi_exception(Code code, const std::string& msg);
 	xdevapi_exception(unsigned int code, const string& msg);
 	xdevapi_exception(unsigned int code, const char* sql_state, const char* msg);
 	xdevapi_exception(unsigned int code, const string& sql_state, const string& msg);
 
 	unsigned int code;
 };
-/* }}} */
 
-/* {{{ mysqlx::util::doc_ref_exception */
 struct doc_ref_exception : public std::runtime_error
 {
 	enum class Severity
@@ -123,7 +133,6 @@ struct doc_ref_exception : public std::runtime_error
 
 	Severity severity;
 };
-/* }}} */
 
 void raise_xdevapi_exception(const xdevapi_exception& e);
 void raise_doc_ref_exception(const doc_ref_exception& e);
@@ -134,6 +143,10 @@ string prepare_reason_msg(unsigned int code, const string& sql_state, const stri
 string prepare_reason_msg(unsigned int code, const char* sql_state, const char* what);
 void log_warning(const string& msg);
 
+void set_error_info(
+	util::xdevapi_exception::Code code,
+	st_mysqlnd_error_info* error_info);
+
 } // namespace util
 
 } // namespace mysqlx
@@ -154,12 +167,3 @@ void log_warning(const string& msg);
 	}
 
 #endif // MYSQL_XDEVAPI_UTIL_EXCEPTIONS_H
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
