@@ -27,9 +27,16 @@ namespace mysqlx {
 
 namespace util {
 
+class zvalue;
+
 namespace json {
 
 void to_zv_string(zval* src, zval* dest);
+util::zvalue to_zv_string(const util::zvalue& src);
+
+bool can_be_document(const util::zvalue& value);
+bool can_be_array(const util::zvalue& value);
+bool can_be_binding(const util::zvalue& value);
 
 void ensure_doc_id(
 	zval* raw_doc,
@@ -63,12 +70,3 @@ using ptree_string = std::string;
 } // namespace mysqlx
 
 #endif // MYSQL_XDEVAPI_UTIL_JSON_UTILS_H
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
