@@ -22,7 +22,6 @@ namespace mysqlx {
 
 namespace util {
 
-/* {{{ to_string */
 string to_string(const zval& zv)
 {
 	switch (Z_TYPE(zv)) {
@@ -48,26 +47,17 @@ string to_string(const zval& zv)
 			throw xdevapi_exception(xdevapi_exception::Code::unsupported_conversion_to_string);
 	}
 }
-/* }}} */
 
-
-/* {{{ string to_string */
 string to_string(const MYSQLND_STRING& s)
 {
 	return string(s.s, s.l);
 }
-/* }}} */
 
-
-/* {{{ string to_string */
 string to_string(const MYSQLND_CSTRING& s)
 {
 	return string(s.s, s.l);
 }
-/* }}} */
 
-
-/* {{{ to_strings */
 strings to_strings(zval* zvals, int count)
 {
 	strings strings;
@@ -77,19 +67,23 @@ strings to_strings(zval* zvals, int count)
 	}
 	return strings;
 }
-/* }}} */
 
+zend_string* to_zend_string(const char* str)
+{
+	return zend_string_init(str, strlen(str), 0);
+}
 
-/* {{{ to_zend_string */
-zend_string* to_zend_string(formatter& fmt)
+zend_string* to_zend_string(const string& str)
 {
-	const string& str = fmt.str();
 	return zend_string_init(str.c_str(), str.length(), 0);
 }
-/* }}} */
 
+zend_string* to_zend_string(formatter& fmt)
+{
+	const string& str{ fmt.str() };
+	return to_zend_string(str);
+}
 
-/* {{{ escape_identifier */
 string
 escape_identifier( const string& identifier ) {
 	std::stringstream result;
@@ -104,10 +98,7 @@ escape_identifier( const string& identifier ) {
 	result << '`';
 	return result.str().c_str();
 }
-/* }}} */
 
-
-/* {{{ to_int */
 bool to_int(const string& str, int* value)
 {
 	try {
@@ -117,17 +108,24 @@ bool to_int(const string& str, int* value)
 		return false;
 	}
 }
-/* }}} */
+
+bool to_int(const std::string& str, int* value)
+{
+	try {
+		*value = std::stoi(str);
+		return true;
+	} catch(std::exception& /*e*/) {
+		return false;
+	}
+}
+
+bool is_alnum_identifier(const std::string& ident)
+{
+	return !ident.empty()
+		&& std::isalpha(ident.front())
+		&& std::all_of(ident.begin() + 1, ident.end(), ::isalnum);
+}
 
 } // namespace util
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
