@@ -22,14 +22,23 @@
 #include "mysqlnd_api.h"
 #include "strings.h"
 #include <boost/algorithm/string/compare.hpp>
+#include <cctype>
 
 namespace mysqlx {
 
 namespace util {
 
-/* {{{ iless */
 struct iless
 {
+	bool operator()(const char* lhs, const char* rhs) const
+	{
+		return std::lexicographical_compare(
+			lhs, lhs + std::strlen(lhs),
+			rhs, rhs + std::strlen(rhs),
+			boost::algorithm::is_iless()
+		);
+	}
+
 	bool operator()(const std::string& lhs, const std::string& rhs) const
 	{
 		return std::lexicographical_compare(
@@ -48,7 +57,6 @@ struct iless
 		);
 	}
 };
-/* }}} */
 
 //------------------------------------------------------------------------------
 
@@ -110,7 +118,6 @@ inline std::string to_std_string(const std::string& str)
 
 strings to_strings(zval* zvals, int count);
 
-/* {{{ to_strings */
 template<typename Pred>
 strings to_strings(zval* zvals, int count, Pred pred)
 {
@@ -121,9 +128,9 @@ strings to_strings(zval* zvals, int count, Pred pred)
 	}
 	return strings;
 }
-/* }}} */
-
 
+zend_string* to_zend_string(const char* str);
+zend_string* to_zend_string(const string& str);
 zend_string* to_zend_string(formatter& fmt);
 
 //------------------------------------------------------------------------------
@@ -147,18 +154,38 @@ inline st_mysqlnd_const_string to_mysqlnd_cstr(const string& str)
 //------------------------------------------------------------------------------
 
 bool to_int(const string& str, int* value);
+bool to_int(const std::string& str, int* value);
+
+bool is_alnum_identifier(const std::string& ident);
+
+//------------------------------------------------------------------------------
+
+template<typename String>
+bool contains_blank(const String& str)
+{
+	return std::find_if(
+		str.begin(),
+		str.end(),
+		[](unsigned char chr){ return std::isblank(chr); }) != str.end();
+}
+
+template<typename String>
+String quotation(const String& str)
+{
+	return "'" + str + "'";
+}
+
+template<typename String>
+String quotation_if_blank(const String& str)
+{
+	if (str.empty() || contains_blank(str)) {
+		return quotation(str);
+	}
+	return str;
+}
 
 } // namespace util
 
 } // namespace mysqlx
 
 #endif // MYSQL_XDEVAPI_UTIL_STRING_UTILS_H
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
