@@ -50,6 +50,10 @@ template<typename CharT, typename Traits = std::char_traits<CharT>>
 using basic_istringstream = std::basic_istringstream<CharT, Traits, allocator<CharT>>;
 using istringstream = basic_istringstream<char>;
 
+template<typename CharT, typename Traits = std::char_traits<CharT>>
+using basic_stringstream = std::basic_stringstream<CharT, Traits, allocator<CharT>>;
+using stringstream = basic_stringstream<char>;
+
 std::ostream& operator<<(std::ostream& os, const string& str);
 
 template<typename CharT, typename Traits = std::char_traits<CharT>>
@@ -76,7 +80,6 @@ using wformatter = basic_formatter<wchar_t>;
 	1) then optionally make some checks (whether is empty or make some 	comparison
 	like == ), or immediately get proper util::string via to_string() member routine
 */
-/* {{{ string_view */
 struct string_view
 {
 	string_view() = default;
@@ -168,19 +171,14 @@ struct string_view
 	const char* str{nullptr};
 	size_t len{0};
 };
-/* }}} */
+
+// ------------------------------------------------------------------------------
+
+using std_strings = std::vector<std::string>;
+using std_stringset = std::set<std::string>;
 
 } // namespace util
 
 } // namespace mysqlx
 
 #endif // MYSQL_XDEVAPI_UTIL_STRINGS_H
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
