@@ -19,6 +19,7 @@
 #include "mysqlnd_api.h"
 #include "zend_utils.h"
 #include "strings.h"
+#include "string_utils.h"
 #include <boost/algorithm/string/classification.hpp>
 #include <boost/algorithm/string/split.hpp>
 
@@ -403,17 +404,24 @@ void verify_call_parameters(
 	verify_parameters.run();
 }
 
+// ------------
+
+bool is_module_loaded(const char* module_name)
+{
+	zend_string* module_zname{ to_zend_string(module_name) };
+	const bool is_loaded{ zend_hash_exists(&module_registry, module_zname) ? true : false };
+	zend_string_release(module_zname);
+	return is_loaded;
+}
+
+bool is_openssl_loaded()
+{
+	const char* Openssl_module_name{ "openssl" };
+	return is_module_loaded(Openssl_module_name);
+}
+
 } // namespace zend
 
 } // namespace util
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
