@@ -71,6 +71,11 @@ int parse_function_parameters(
 		std::forward<Params>(params)...);
 }
 
+// ----------------
+
+bool is_module_loaded(const char* module_name);
+bool is_openssl_loaded();
+
 } // namespace zend
 
 } // namespace util
@@ -78,12 +83,3 @@ int parse_function_parameters(
 } // namespace mysqlx
 
 #endif // MYSQL_XDEVAPI_UTIL_ZEND_UTILS_H
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
