@@ -21,22 +21,23 @@
 
 #include <mysql/cdk/foundation/error.h>
 
-PUSH_SYS_WARNINGS
+PUSH_SYS_WARNINGS_CDK
 #include <stdexcept>
 #include <sstream>
-POP_SYS_WARNINGS
+POP_SYS_WARNINGS_CDK
 
 
 namespace cdk {
 namespace foundation {
 
+using std::string;
 
 /*
   Default prefix added to error description in the string returned by
   what().
 */
 
-const string Error::m_default_prefix = L"CDK Error: ";
+const string Error::m_default_prefix = "CDK Error: ";
 
 
 void Error::description_materialize() const
