@@ -19,10 +19,9 @@
 
 #include "common.h"
 
-PUSH_SYS_WARNINGS
+PUSH_SYS_WARNINGS_CDK
 #include <time.h>
-POP_SYS_WARNINGS
-
+POP_SYS_WARNINGS_CDK
 
 namespace cdk {
 namespace foundation {
