@@ -17,24 +17,26 @@
 #ifndef SDK_FOUNDATION_TYPES_H
 #define SDK_FOUNDATION_TYPES_H
 
+
 #include "common.h"
 #include "cdk_time.h"
+#include "string.h"
 
 // TODO: Replace with std::variant<> when available.
 #include "variant.h"
 
-PUSH_SYS_WARNINGS
+PUSH_SYS_WARNINGS_CDK
 #include <stdint.h>
 #include <string.h>
 #include <string>
 #include <memory>
-POP_SYS_WARNINGS
+POP_SYS_WARNINGS_CDK
 
+#undef byte
 
 namespace cdk {
 namespace foundation {
 
-typedef wchar_t      char_t;
 
 /*
   Note: we do not include error.h from here because this would create
@@ -44,51 +46,6 @@ typedef wchar_t      char_t;
 void throw_error(const char*);
 
 
-class string : public std::wstring
-{
-public:
-
-  string() {}
-  string(const wchar_t *str) : std::wstring(str) {}
-  string(const std::wstring &str) : std::wstring(str) {}
-
-  string(const char *str) { set_utf8(str); }
-  string(const std::string &str) { set_utf8(str); }
-
-  // internal -> UTF8 conversion
-  operator std::string() const;
-
-  // UTF8 -> internal conversion
-  string& set_utf8(const std::string&);
-};
-
-inline
-std::ostream& operator<<(std::ostream &out, const string &str)
-{
-  return out << (std::string)str;
-}
-
-
-#ifdef USE_NATIVE_BYTE
-  using ::byte;
-#else
-  typedef unsigned char byte;
-#endif
-
-/*
-  Convenience class to disable copy constructor in a derived class.
-*/
-
-class nocopy
-{
-  nocopy(const nocopy&);
-  nocopy& operator=(const nocopy&);
-
-protected:
-  nocopy() {}
-};
-
-
 class Iterator
 {
 public:
@@ -119,6 +76,7 @@ public:
   bytes(const char *str)
     : m_begin((byte*)str), m_end(m_begin + strlen(str))
   {}
+  virtual ~bytes(){}
 
   virtual byte* begin() const { return m_begin; }
   virtual byte* end() const { return m_end; }
@@ -259,15 +217,15 @@ public:
   */
 
 #ifdef __clang__
-  DIAGNOSTIC_PUSH
-  DISABLE_WARNING(-Wc++11-extensions)
+  DIAGNOSTIC_PUSH_CDK
+  DISABLE_WARNING_CDK(-Wc++11-extensions)
 #endif
 
 private:
   scoped_ptr(scoped_ptr&&);
 
 #ifdef __clang__
-  DIAGNOSTIC_POP
+  DIAGNOSTIC_POP_CDK
 #endif
 
 #endif
