@@ -12,21 +12,17 @@
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
-*/
+ */
 
 
 #include "expr_parser.h"
 
-PUSH_SYS_WARNINGS
+PUSH_SYS_WARNINGS_CDK
 #include <stdlib.h>
-POP_SYS_WARNINGS
-
-
-// TODO: Complete the parser
+POP_SYS_WARNINGS_CDK
 
 
 using namespace parser;
-using cdk::string;
 using cdk::Expression;
 typedef cdk::Expression::Processor Processor;
 typedef Processor::List_prc List_prc;
@@ -102,7 +98,7 @@ public:
 
 
 /*
-  Sink expression processor that ignores the expression reproted
+  Sink expression processor that ignores the expression reported
   to it.
 
   It is used below in situations where we want to ignore results
@@ -153,7 +149,7 @@ bool Expr_parser_base::parse_cast(Scalar_prc *prc)
 
   Safe_prc<List_prc> ap = safe_prc(prc)->op(Op::name(Op::CAST));
 
-  consume_token_throw(Token::LPAREN, L"Expected '(' after CAST");
+  consume_token_throw(Token::LPAREN, "Expected '(' after CAST");
 
   ap->list_begin();
 
@@ -162,7 +158,7 @@ bool Expr_parser_base::parse_cast(Scalar_prc *prc)
   delete parse(FULL, ignore_if(ap->list_el()));
 
   consume_token_throw(Keyword::AS,
-    L"Expected AS after expression inside CAST operator");
+    "Expected AS after expression inside CAST operator");
 
   // 2nd arg, cast_data_type
 
@@ -173,7 +169,7 @@ bool Expr_parser_base::parse_cast(Scalar_prc *prc)
   ap->list_end();
 
   consume_token_throw(Token::RPAREN,
-    L"Expected ')' closing CAST operator call");
+    "Expected ')' closing CAST operator call");
 
   return true;
 }
@@ -202,9 +198,13 @@ std::string Expr_parser_base::parse_cast_type()
   const Token* token = consume_token();
 
   if (!token)
-    parse_error(L"Expected cast type");
+    parse_error("Expected cast type");
 
   Keyword::Type type = Keyword::get(*token);
+
+  if (Keyword::NONE == type)
+    parse_error("Unexpected cast type");
+
   type_str = Keyword::name(type);
 
   switch (type)
@@ -232,7 +232,7 @@ std::string Expr_parser_base::parse_cast_type()
     break;
 
   default:
-    parse_error(L"Expected cast type");
+    parse_error("Unexpected cast type");
 
   }
 
@@ -251,24 +251,28 @@ std::string Expr_parser_base::parse_cast_type()
 
 std::string Expr_parser_base::cast_data_type_dimension(bool double_dimension)
 {
-  consume_token_throw(Token::LPAREN, L"Expected type dimension specification");
+  consume_token_throw(Token::LPAREN, "Expected type dimension specification");
+
   std::string result("(");
+
   result += consume_token_throw(
-              Token::INTEGER,
-              L"Expected integer type dimension"
-            ).get_text();
+    Token::INTEGER,
+    "Expected integer type dimension"
+  ).get_utf8();
+
   if (double_dimension && consume_token(Token::COMMA))
   {
     result += ",";
     result += consume_token_throw(
                 Token::INTEGER,
-                L"Expected second type dimension after ','"
-              ).get_text();
+                "Expected second type dimension after ','"
+              ).get_utf8();
   }
+
   result += ")";
   consume_token_throw(
     Token::RPAREN,
-    L"Expected ')' closing type dimension specification"
+    "Expected ')' closing type dimension specification"
   );
   return result;
 }
@@ -289,7 +293,7 @@ bool Expr_parser_base::get_ident(string &id)
 
   if (Token_base::cur_token_type_in({ Token::WORD, Token::QWORD }))
   {
-    id = consume_token()->get_text();
+    id = consume_token()->get_utf8();
     return true;
   }
 
@@ -317,10 +321,10 @@ Expr_parser_base::parse_function_call(const cdk::api::Table_ref &func, Scalar_pr
 
   // Report position(.. IN ..) as locate(...,...)
 
-  if (! qualified && Keyword::equal(func.name(), L"position"))
+  if (! qualified && Keyword::equal(func.name(), "position"))
   {
     Table_ref locate;
-    locate.set(L"locate");
+    locate.set("locate");
     aprc = safe_prc(prc)->call(locate);
     parse_position = true;
   }
@@ -333,14 +337,14 @@ Expr_parser_base::parse_function_call(const cdk::api::Table_ref &func, Scalar_pr
   if (!cur_token_type_is(Token::RPAREN))
   {
     if (
-      !qualified && Keyword::equal(func.name(), L"trim")
+      !qualified && Keyword::equal(func.name(), "trim")
       && cur_token_type_in({
            Keyword::BOTH, Keyword::LEADING, Keyword::TRAILING
          })
     )
-      unsupported(L"LEADING, TRAILING or BOTH clause inside function TRIM()");
+      unsupported("LEADING, TRAILING or BOTH clause inside function TRIM()");
 
-    parse(parse_position ? COMP : FULL, aprc ? aprc->list_el() : NULL);
+    delete parse(parse_position ? COMP : FULL, aprc ? aprc->list_el() : NULL);
 
     if (consume_token(Token::COMMA))
       parse_argslist(aprc);
@@ -353,7 +357,7 @@ Expr_parser_base::parse_function_call(const cdk::api::Table_ref &func, Scalar_pr
 
   consume_token_throw(
     Token::RPAREN,
-    L"Expected ')' to close function argument list"
+    "Expected ')' to close function argument list"
   );
 
   return true;
@@ -369,24 +373,24 @@ Expr_parser_base::parse_special_args(
   if (func.schema())
     return;
 
-  if (Keyword::equal(func.name(), L"char"))
+  if (Keyword::equal(func.name(), "char"))
   {
     if (cur_token_type_is(Keyword::USING))
-      unsupported(L"USING clause inside function CHAR()");
+      unsupported("USING clause inside function CHAR()");
     return;
   }
 
-  if (Keyword::equal(func.name(), L"trim"))
+  if (Keyword::equal(func.name(), "trim"))
   {
     if (cur_token_type_is(Keyword::FROM))
-      unsupported(L"FROM clause inside function TRIM()");
+      unsupported("FROM clause inside function TRIM()");
   }
 
-  if (Keyword::equal(func.name(), L"position"))
+  if (Keyword::equal(func.name(), "position"))
   {
     if (!consume_token(Keyword::IN))
       parse_error("Expected IN inside POSITION(... IN ...)");
-    parse(FULL, aprc ? aprc->list_el() : NULL);
+    delete parse(FULL, aprc ? aprc->list_el() : NULL);
     return;
   }
 }
@@ -460,19 +464,24 @@ bool Expr_parser_base::parse_schema_ident(Token::Type (*types)[2])
 
 void Expr_parser_base::parse_column_ident(Path_prc *prc)
 {
-  parse_schema_ident();
+  if (!parse_schema_ident())
+    parse_error("Expected a column identifier");
   parse_column_ident1(prc);
 }
 
 
 void Expr_parser_base::parse_column_ident1(Path_prc *prc)
 {
+  /*
+    Note: at this point we assume that an (possibly schema qualified) identifier
+    has been already seen and is stored in m_col_ref.table()
+  */
   if (consume_token(Token::DOT))
   {
     string name;
 
     if (!get_ident(name))
-      parse_error(L"Expected identifier after '.'");
+      parse_error("Expected identifier after '.'");
     // Note: the table part was initialized in parse_schema_ident()
     m_col_ref.set_name(name);
   }
@@ -480,11 +489,13 @@ void Expr_parser_base::parse_column_ident1(Path_prc *prc)
   {
     // Re-interpret table name parsed by parse_schema_ident() as a
     // column name of the form [<table>.]<column>
+    auto table = m_col_ref.table();
+    assert(table);
 
-    if (m_col_ref.table()->schema())
-      m_col_ref.set(m_col_ref.table()->name(), m_col_ref.table()->schema()->name());
+    if (table->schema())
+      m_col_ref.set(table->name(), table->schema()->name());
     else
-      m_col_ref.set(m_col_ref.table()->name());
+      m_col_ref.set(table->name());
   }
 
   if (consume_token(Token::ARROW) || consume_token(Token::ARROW2))
@@ -492,14 +503,14 @@ void Expr_parser_base::parse_column_ident1(Path_prc *prc)
 
     if (Token_base::cur_token_type_in({ Token::QSTRING, Token::QQSTRING }))
     {
-      Tokenizer toks(consume_token()->get_text());
+      Tokenizer toks(consume_token()->get_bytes());
       It first = toks.begin();
       It last  = toks.end();
       Expr_parser_base path_parser(first, last, m_parser_mode);
       // TODO: Translate parse errors
       path_parser.parse_document_field(prc, true);
       if (first != last)
-        parse_error(L"Unexpected characters in a quotted path component");
+        parse_error("Unexpected characters in a quoted path component");
     }
     else
     {
@@ -549,10 +560,10 @@ void Expr_parser_base::parse_document_field(Path_prc *prc, bool prefix)
   }
 
   if (prefix)
-    parse_error(L"Expected '$' to start a document path");
+    parse_error("Expected '$' to start a document path");
 
   if (!parse_document_path(prc, false))
-    parse_error(L"Expected a document path");
+    parse_error("Expected a document path");
 }
 
 
@@ -612,7 +623,7 @@ void Expr_parser_base::parse_document_field(const string &first,
      correct - array locations should be possible only after a path to some
      array member.
 
-  2. It always requires a DOT befre a member element, but in some contexts
+  2. It always requires a DOT before a member element, but in some contexts
      we want a document path like "foo.bar.baz" to start without a dot.
 
   To deal with this the grammar has been changed and require_dot parameter
@@ -662,7 +673,7 @@ bool Expr_parser_base::parse_document_path(Path_prc *prc, bool require_dot)
     parse_docpath_member() it will become evident.
 
     The Path_el_reporter wrapper around path processor solves this problem by
-    deffering the initial list_begin() call and the list_el() calls to the
+    deferring the initial list_begin() call and the list_el() calls to the
     moment when a path element is reported. If no path elements are reported
     then list_begin() or list_el() will not be called. Similar, call to
     list_end() will be forwarded to the wrapped processor only if list_begin()
@@ -768,7 +779,7 @@ bool Expr_parser_base::parse_document_path(Path_prc *prc, bool require_dot)
   bool ret = parse_document_path1(&el_reporter);
 
   if (!ret && double_star)
-    parse_error(L"Document path ending in '**'");
+    parse_error("Document path ending in '**'");
 
   el_reporter.list_end();
 
@@ -824,7 +835,7 @@ bool Expr_parser_base::parse_document_path1(Path_prc *prc)
   }
 
   if (last_double_star)
-    parse_error(L"Document path ending in '**'");
+    parse_error("Document path ending in '**'");
 
   return has_item;
 }
@@ -871,7 +882,7 @@ bool Expr_parser_base::parse_docpath_member_dot(Path_prc *prc)
   if (!consume_token(Token::DOT))
     return false;
   if (!parse_docpath_member(prc))
-    parse_error(L"Expected member name or '*' after '.' in a document path");
+    parse_error("Expected member name or '*' after '.' in a document path");
   return true;
 }
 
@@ -895,12 +906,12 @@ bool Expr_parser_base::parse_docpath_array(Path_prc *prc)
   else
   {
     if (!cur_token_type_is(Token::INTEGER))
-      parse_error(L"Expected '*' or integer index after '[' in a document path");
+      parse_error("Expected '*' or integer index after '[' in a document path");
 
     uint64_t v;
 
     try {
-      v = strtoui(consume_token()->get_text());
+      v = strtoui(consume_token()->get_utf8());
     }
     catch (const Numeric_conversion_error &e)
     {
@@ -909,14 +920,14 @@ bool Expr_parser_base::parse_docpath_array(Path_prc *prc)
     }
 
     if (v > std::numeric_limits<Path_prc::Element_prc::index_t>::max())
-      parse_error(L"Array index too large");
+      parse_error("Array index too large");
 
     safe_prc(prc)->list_el()->index(Path_prc::Element_prc::index_t(v));
   }
 
   consume_token_throw(
     Token::RSQBRACKET,
-    L"Expected ']' to close a document path array component"
+    "Expected ']' to close a document path array component"
   );
   return true;
 }
@@ -1036,7 +1047,7 @@ bool column_ref_from_path(cdk::Doc_path &path, parser::Column_ref &column)
 Expression* Expr_parser_base::parse_atomic(Processor *prc)
 {
   if (!tokens_available())
-    parse_error(L"Expected an expression");
+    parse_error("Expected an expression");
 
   Token::Type type = peek_token()->get_type();
 
@@ -1057,12 +1068,12 @@ Expression* Expr_parser_base::parse_atomic(Processor *prc)
   case Token::LPAREN:
   {
     consume_token();
-    Expression *res = parse(FULL, prc);
+    smart_ptr<Expression> res(parse(FULL, prc));
     consume_token_throw(
       Token::RPAREN,
-      L"Expected ')' to close parenthesized sub-expression"
+      "Expected ')' to close parenthesized sub-expression"
     );
-    return res;
+    return res.release();
   }
 
   default: break;
@@ -1091,7 +1102,7 @@ Expression* Expr_parser_base::parse_atomic(Processor *prc)
   {
     sprc->param(consume_token_throw(
       Token::WORD,
-      L"Expected parameter name after ':'"
+      "Expected parameter name after ':'"
     ).get_text());
     return stored.release();
   }
@@ -1154,7 +1165,7 @@ Expression* Expr_parser_base::parse_atomic(Processor *prc)
   if (argsp)
   {
     argsp->list_begin();
-    parse(ATOMIC, argsp->list_el());
+    delete parse(ATOMIC, argsp->list_el());
     argsp->list_end();
     return stored.release();
   }
@@ -1194,9 +1205,9 @@ Expression* Expr_parser_base::parse_atomic(Processor *prc)
     case Token::QSTRING:
       if (m_strings_as_blobs)
       {
-        // NOTE: if string is reported as blob, it gets converted to utf8
-        sprc->val()->value(cdk::TYPE_BYTES, Format_info(),
-          cdk::bytes(consume_token()->get_text()));
+        sprc->val()->value(
+          cdk::TYPE_BYTES, Format_info(), consume_token()->get_bytes()
+        );
       }
       else
         sprc->val()->str(consume_token()->get_text());
@@ -1204,7 +1215,7 @@ Expression* Expr_parser_base::parse_atomic(Processor *prc)
 
     case Token::NUMBER:
       {
-        double val = strtod(consume_token()->get_text());
+        double val = strtod(consume_token()->get_utf8());
         sprc->val()->num(neg ? -val : val);
         return stored.release();
       }
@@ -1212,12 +1223,12 @@ Expression* Expr_parser_base::parse_atomic(Processor *prc)
     case Token::INTEGER:
       if (neg)
       {
-        int64_t val = strtoi(consume_token()->get_text());
+        int64_t val = strtoi(consume_token()->get_utf8());
         sprc->val()->num(-val);
       }
       else
       {
-        uint64_t val = strtoui(consume_token()->get_text());
+        uint64_t val = strtoui(consume_token()->get_utf8());
         sprc->val()->num(val);
       }
       return stored.release();
@@ -1225,12 +1236,12 @@ Expression* Expr_parser_base::parse_atomic(Processor *prc)
     case Token::HEX:
       if (neg)
       {
-        int64_t val = strtoi(consume_token()->get_text(), 16);
+        int64_t val = strtoi(consume_token()->get_utf8(), 16);
         sprc->val()->num(-val);
       }
       else
       {
-        uint64_t val = strtoui(consume_token()->get_text(), 16);
+        uint64_t val = strtoui(consume_token()->get_utf8(), 16);
         sprc->val()->num(val);
       }
       return stored.release();
@@ -1324,8 +1335,8 @@ Expression* Expr_parser_base::parse_atomic(Processor *prc)
   /*
     Here we know that we are in DOCUMENT mode and we are expecting a document
     path. If parse_schema_ident() called above consumed some tokens, we check
-    if they were not quotted identifiers. Such identifiers are allowed when
-    reffering to tables or columns but are invalid in a document path.
+    if they were not quoted identifiers. Such identifiers are allowed when
+    referring to tables or columns but are invalid in a document path.
   */
 
   if (Token::QWORD == types[0] || Token::QWORD == types[1])
@@ -1333,7 +1344,7 @@ Expression* Expr_parser_base::parse_atomic(Processor *prc)
 
   /*
     Now we treat the identifiers "A.B" parsed by parse_schema_ident() and
-    stored as table/schema name in m_col_ref (if any), as an initail segment
+    stored as table/schema name in m_col_ref (if any), as an initial segment
     of a document field reference and complete parsing the whole document
     field.
   */
@@ -1418,7 +1429,7 @@ Expr_parser_base::left_assoc_binary_op(const Op::Set &ops,
 
     // then parse rhs, passing it as 2nd argument
 
-    parse(rhs, aprc->list_el());
+    delete parse(rhs, aprc->list_el());
 
     aprc->list_end();
   }
@@ -1468,7 +1479,7 @@ Expression* Expr_parser_base::parse_bit(Processor *prc)
     if (argsp)
     {
       argsp->list_begin();
-      parse(ATOMIC, argsp->list_el());
+      delete parse(ATOMIC, argsp->list_el());
       argsp->list_end();
       return stored.release();
     }
@@ -1510,14 +1521,14 @@ Expression* Expr_parser_base::parse_or(Processor *prc)
 
 /**
    Expression Parser EBNF:
-   note; No reptetition, must be connected by logical operators
+   note; No repetition, must be connected by logical operators
     ilriExpr ::=
             compExpr IS NOT? (NULL|TRUE|FALSE)
         |   compExpr NOT? IN LPAREN argsList? RPAREN
         |   compExpr NOT? "IN" compExpr
-            // TODO: param to ESCAPE should be better defined
-        |   compExpr NOT? LIKE compExpr (ESCAPE compExpr)?
-        |   compExpr NOT? RLIKE compExpr (ESCAPE compExpr)?
+            // TODO: we don't know how to report ESCAPE on protocol level
+        |   compExpr NOT? LIKE compExpr //(ESCAPE compExpr)?
+        |   compExpr NOT? RLIKE compExpr //(ESCAPE compExpr)?
         |   compExpr NOT? BETWEEN compExpr AND compExpr
         |   compExpr NOT? REGEXP compExpr
 
@@ -1546,6 +1557,7 @@ Expression* Expr_parser_base::parse_ilri(Processor *prc)
   next.insert(Op::BETWEEN);
   next.insert(Op::REGEXP);
   next.insert(Op::SOUNDS_LIKE);
+  next.insert(Op::OVERLAPS);
 
   const Token *t = consume_token(next);
 
@@ -1557,7 +1569,7 @@ Expression* Expr_parser_base::parse_ilri(Processor *prc)
   if (!t)
   {
     if (neg)
-      parse_error(L"Expected IN, (R)LIKE, BETWEEN or REGEXP after NOT");
+      parse_error("Expected IN, (R)LIKE, BETWEEN, OVERLAPS or REGEXP after NOT");
 
     // If prc is NULL return already stored expression.
 
@@ -1570,25 +1582,28 @@ Expression* Expr_parser_base::parse_ilri(Processor *prc)
     return NULL;
   }
 
-  // Handle IS NOT case.
-
-  if (neg && Op::IS == *t)
-    parse_error(L"Operator NOT before IS, should be IS NOT");
-
-  if (Op::IS == *t && consume_token(Op::NOT))
-    neg = true;
-
   // We have an ilri expression with operator and 2 arguments.
 
   Op::Type op = Op::get_binary(*t);
 
-  // Detect unsupported operators before handling parmaeters
+  // Handle IS NOT case.
+
+  if (neg && Op::IS == op)
+    parse_error("Operator NOT before IS, should be IS NOT");
+
+  // Note: consume_token() replaces contents of *t...
+
+  if (Op::IS == op && consume_token(Op::NOT))
+    neg = true;
+
+
+  // Detect unsupported operators before handling parameters
 
   switch (op)
   {
   case Op::SOUNDS_LIKE:
     if (cur_token_type_is(Keyword::LIKE))
-      unsupported(L"Operator SOUNDS LIKE");
+      unsupported("Operator SOUNDS LIKE");
     break;
   case Op::IS:
     if (neg)
@@ -1624,12 +1639,15 @@ Expression* Expr_parser_base::parse_ilri(Processor *prc)
     if (neg)
       op = Op::NOT_REGEXP;
     break;
-
+  case Op::OVERLAPS:
+      if (neg)
+    op = Op::NOT_OVERLAPS;
+      break;
   default: break;
   }
 
   /*
-    If prc is NULL and we are supposed to store parsed epression, use
+    If prc is NULL and we are supposed to store parsed expression, use
     specialized Stored_ilri class that can re-use the already stored first
     part of the expression.
   */
@@ -1665,7 +1683,7 @@ Expression* Expr_parser_base::parse_ilri(Processor *prc)
         switch (Keyword::get(*t))
         {
         case Keyword::L_TRUE:  aprc->list_el()->scalar()->val()->yesno(true); break;
-        case Keyword::L_FALSE: aprc->list_el()->scalar()->val()->yesno(true); break;
+        case Keyword::L_FALSE: aprc->list_el()->scalar()->val()->yesno(false); break;
         case Keyword::L_NULL: aprc->list_el()->scalar()->val()->null(); break;
         default:
           t = NULL; // this indicates error
@@ -1690,12 +1708,12 @@ Expression* Expr_parser_base::parse_ilri(Processor *prc)
 
         consume_token_throw(
               Token::RPAREN,
-              L"Expected ')' to close IN(... expression"
+              "Expected ')' to close IN(... expression"
               );
       }
       else
       {
-        parse(COMP, aprc->list_el());
+        delete parse(COMP, aprc->list_el());
       }
 
       break;
@@ -1706,11 +1724,10 @@ Expression* Expr_parser_base::parse_ilri(Processor *prc)
     case Op::RLIKE:
     case Op::NOT_RLIKE:
     {
-      parse(COMP, aprc->list_el());
+      delete parse(COMP, aprc->list_el());
 
       if (cur_token_type_is(Keyword::ESCAPE))
       {
-        //TODO: Check ESCAPE
         unsupported("ESCAPE clause for (R)LIKE operator");
       }
 
@@ -1719,17 +1736,22 @@ Expression* Expr_parser_base::parse_ilri(Processor *prc)
 
     case Op::REGEXP:
     case Op::NOT_REGEXP:
-      parse(COMP, aprc->list_el());
+      delete parse(COMP, aprc->list_el());
+      break;
+
+    case Op::OVERLAPS:
+    case Op::NOT_OVERLAPS:
+      delete parse(COMP, aprc->list_el());
       break;
 
     case Op::BETWEEN:
     case Op::NOT_BETWEEN:
-      parse(COMP, aprc->list_el());
+      delete parse(COMP, aprc->list_el());
       consume_token_throw(
         Keyword::AND,
-        L"Expected AND in BETWEEN ... expression"
+        "Expected AND in BETWEEN ... expression"
       );
-      parse(COMP, aprc->list_el());
+      delete parse(COMP, aprc->list_el());
       break;
 
     default: assert(false);
@@ -1756,7 +1778,7 @@ Expression* Expr_parser_base::parse_ilri(Processor *prc)
   But Expr_parser_base constructor also needs parser mode parameter
   and the flag which tells if strings should be reported as blobs.
   To fix this, we define Base_parser<> template parametrized with parser
-  mode, which will construct required flavour of the parser.
+  mode, which will construct required flavor of the parser.
 */
 
 template <Parser_mode::value Mode,
@@ -1934,15 +1956,15 @@ void Projection_parser::parse_doc_mode(Document_processor& prc)
 
   // AS is mandatory on Collections
   if (!consume_token(Keyword::AS))
-    parse_error(L"Expected AS in projection specification");
+    parse_error("Expected AS in projection specification");
 
   if (!Token_base::cur_token_type_in({Token::WORD,Token::QWORD}))
-    parse_error(L"Expected identifier after AS");
+    parse_error("Expected identifier after AS");
 
   const string &id = consume_token()->get_text();
 
   if (tokens_available())
-    parse_error(L"Invalid characters after projection specification");
+    parse_error("Invalid characters after projection specification");
 
   store_expr.process_if(prc.key_val(id));
 }
