@@ -36,7 +36,6 @@ namespace mysqlx {
 
 namespace drv {
 
-/* {{{ xmysqlnd_collection::xmysqlnd_collection */
 xmysqlnd_collection::xmysqlnd_collection(
 								xmysqlnd_schema * const cur_schema,
 								const MYSQLND_CSTRING cur_collection_name,
@@ -51,7 +50,6 @@ xmysqlnd_collection::xmysqlnd_collection(
 	DBG_INF_FMT("name=[%d]%*s", collection_name.l, collection_name.l, collection_name.s);
 
 }
-/* }}} */
 
 struct st_collection_exists_in_database_var_binder_ctx
 {
@@ -61,7 +59,6 @@ struct st_collection_exists_in_database_var_binder_ctx
 };
 
 
-/* {{{ collection_op_var_binder */
 static const enum_hnd_func_status
 collection_op_var_binder(
 	void * context,
@@ -103,8 +100,6 @@ bind:
 	++ctx->counter;
 	DBG_RETURN(ret);
 }
-/* }}} */
-
 
 struct collection_exists_in_database_ctx
 {
@@ -113,7 +108,6 @@ struct collection_exists_in_database_ctx
 };
 
 
-/* {{{ collection_xplugin_op_on_row */
 static const enum_hnd_func_status
 collection_xplugin_op_on_row(
 	void * context,
@@ -142,10 +136,7 @@ collection_xplugin_op_on_row(
 	}
 	DBG_RETURN(HND_AGAIN);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection::exists_in_database */
 enum_func_status
 xmysqlnd_collection::exists_in_database(
 	struct st_xmysqlnd_session_on_error_bind on_error,
@@ -183,8 +174,6 @@ xmysqlnd_collection::exists_in_database(
 
 	DBG_RETURN(ret);
 }
-/* }}} */
-
 
 struct st_collection_sql_single_result_ctx
 {
@@ -192,7 +181,6 @@ struct st_collection_sql_single_result_ctx
 };
 
 
-/* {{{ collection_xplugin_op_on_row */
 static const enum_hnd_func_status
 collection_sql_single_result_op_on_row(
 	void * context,
@@ -210,10 +198,7 @@ collection_sql_single_result_op_on_row(
 	}
 	DBG_RETURN(HND_AGAIN);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection::count */
 enum_func_status
 xmysqlnd_collection::count(
 	struct st_xmysqlnd_session_on_error_bind on_error,
@@ -252,9 +237,7 @@ xmysqlnd_collection::count(
 	mnd_sprintf_free(query_str);
 	DBG_RETURN(ret);
 }
-/* }}} */
 
-/* {{{ xmysqlnd_collection::add */
 xmysqlnd_stmt *
 xmysqlnd_collection::add(XMYSQLND_CRUD_COLLECTION_OP__ADD * crud_op)
 {
@@ -280,10 +263,7 @@ xmysqlnd_collection::add(XMYSQLND_CRUD_COLLECTION_OP__ADD * crud_op)
 
 	DBG_RETURN(ret);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection::remove */
 xmysqlnd_stmt *
 xmysqlnd_collection::remove(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * op)
 {
@@ -310,7 +290,7 @@ xmysqlnd_collection::remove(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * op)
 			DBG_INF(stmt != nullptr? "PASS":"FAIL");
 		}
 	}else{
-		auto res = ps_data->add_message( op->message, static_cast<uint32_t>(op->bound_values.size()));
+		auto res = ps_data->add_message( op->message, static_cast<uint32_t>(op->bindings.size()));
 		if (!op || FAIL == xmysqlnd_crud_collection_remove__finalize_bind(op)) {
 			DBG_RETURN(stmt);
 		}
@@ -332,17 +312,14 @@ xmysqlnd_collection::remove(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * op)
 		}
 
 		if( ps_data->prepare_msg_delivered( res.second ) &&
-			ps_data->bind_values( res.second, op->bound_values ) ) {
+			ps_data->bind_values( res.second, op->bindings.get_bound_values() ) ) {
 			stmt = ps_data->send_execute_msg( res.second );
 		}
 	}
 
 	DBG_RETURN(stmt);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection::modify */
 xmysqlnd_stmt *
 xmysqlnd_collection::modify(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * op)
 {
@@ -356,7 +333,7 @@ xmysqlnd_collection::modify(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * op)
 	}
 	if( false == ps_data->is_ps_supported() ) {
 		if ( !ps_data->is_bind_finalized( op->ps_message_id ) &&
-			 FAIL == xmysqlnd_crud_collection_modify__finalize_bind(op)) {
+			 !xmysqlnd_crud_collection_modify__finalize_bind(op)) {
 			DBG_RETURN(stmt);
 		}
 		if (xmysqlnd_crud_collection_modify__is_initialized(op)) {
@@ -369,8 +346,8 @@ xmysqlnd_collection::modify(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * op)
 		}
 		DBG_INF(stmt != nullptr? "PASS":"FAIL");
 	} else {
-		auto res = ps_data->add_message( op->message, static_cast<uint32_t>(op->bound_values.size()) );
-		if ( FAIL == xmysqlnd_crud_collection_modify__finalize_bind(op)) {
+		auto res = ps_data->add_message( op->message, static_cast<uint32_t>(op->bindings.size()) );
+		if (!xmysqlnd_crud_collection_modify__finalize_bind(op)) {
 			DBG_RETURN(stmt);
 		}
 		op->ps_message_id = res.second;
@@ -390,17 +367,14 @@ xmysqlnd_collection::modify(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * op)
 		}
 
 		if( ps_data->prepare_msg_delivered( res.second ) &&
-			ps_data->bind_values( res.second, op->bound_values ) ) {
+			ps_data->bind_values( res.second, op->bindings.get_bound_values() ) ) {
 			stmt = ps_data->send_execute_msg( res.second );
 		}
 	}
 
 	DBG_RETURN(stmt);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection::find */
 xmysqlnd_stmt*
 xmysqlnd_collection::find(XMYSQLND_CRUD_COLLECTION_OP__FIND * op)
 {
@@ -427,7 +401,7 @@ xmysqlnd_collection::find(XMYSQLND_CRUD_COLLECTION_OP__FIND * op)
 			}
 		}
 	} else {
-		auto res = ps_data->add_message( op->message, static_cast<uint32_t>(op->bound_values.size()) );
+		auto res = ps_data->add_message( op->message, static_cast<uint32_t>(op->bindings.size()) );
 		if ( FAIL == xmysqlnd_crud_collection_find__finalize_bind(op) ) {
 			DBG_RETURN(stmt);
 		}
@@ -442,16 +416,13 @@ xmysqlnd_collection::find(XMYSQLND_CRUD_COLLECTION_OP__FIND * op)
 			}
 		}
 		if( ps_data->prepare_msg_delivered( res.second ) &&
-			ps_data->bind_values( res.second, op->bound_values ) ) {
+			ps_data->bind_values( res.second, op->bindings.get_bound_values() ) ) {
 			stmt = ps_data->send_execute_msg( res.second );
 		}
 	}
 	DBG_RETURN(stmt);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection::get_reference */
 xmysqlnd_collection *
 xmysqlnd_collection::get_reference()
 {
@@ -460,10 +431,7 @@ xmysqlnd_collection::get_reference()
 	DBG_INF_FMT("new_refcount=%u", refcount);
 	DBG_RETURN(this);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection::free_reference */
 enum_func_status
 xmysqlnd_collection::free_reference(MYSQLND_STATS * stats, MYSQLND_ERROR_INFO * error_info)
 {
@@ -475,10 +443,7 @@ xmysqlnd_collection::free_reference(MYSQLND_STATS * stats, MYSQLND_ERROR_INFO *
 	}
 	DBG_RETURN(ret);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection::free_contents */
 void
 xmysqlnd_collection::free_contents()
 {
@@ -489,10 +454,7 @@ xmysqlnd_collection::free_contents()
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection::cleanup */
 void
 xmysqlnd_collection::cleanup(MYSQLND_STATS * stats, MYSQLND_ERROR_INFO * error_info)
 {
@@ -502,10 +464,7 @@ xmysqlnd_collection::cleanup(MYSQLND_STATS * stats, MYSQLND_ERROR_INFO * error_i
 
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection_create */
 PHP_MYSQL_XDEVAPI_API xmysqlnd_collection *
 xmysqlnd_collection_create(xmysqlnd_schema * schema,
 								const MYSQLND_CSTRING collection_name,
@@ -524,10 +483,7 @@ xmysqlnd_collection_create(xmysqlnd_schema * schema,
 	}
 	DBG_RETURN(ret);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_collection_free */
 PHP_MYSQL_XDEVAPI_API void
 xmysqlnd_collection_free(xmysqlnd_collection * const collection, MYSQLND_STATS * stats, MYSQLND_ERROR_INFO * error_info)
 {
@@ -539,17 +495,7 @@ xmysqlnd_collection_free(xmysqlnd_collection * const collection, MYSQLND_STATS *
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
 } // namespace drv
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
