@@ -13,6 +13,8 @@
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Andrey Hristov <andrey@php.net>                             |
+  |          Filip Janiszewski <fjanisze@php.net>                        |
+  |          Darek Slusarczyk <marines@php.net>                          |
   +----------------------------------------------------------------------+
 */
 #ifndef XMYSQLND_CRUD_COLLECTION_COMMANDS_H
@@ -25,6 +27,8 @@
 #include "xmysqlnd_crud_collection_commands.h"
 #include "xmysqlnd/crud_parsers/mysqlx_crud_parser.h"
 #include "xmysqlnd/crud_parsers/expression_parser.h"
+#include "util/types.h"
+#include "util/value.h"
 
 namespace Mysqlx { namespace Sql { class StmtExecute; } }
 
@@ -47,50 +51,61 @@ void xmysqlnd_crud_collection_remove__destroy(XMYSQLND_CRUD_COLLECTION_OP__REMOV
 enum_func_status xmysqlnd_crud_collection_remove__set_criteria(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * obj, const std::string& criteria);
 enum_func_status xmysqlnd_crud_collection_remove__set_limit(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * obj, const size_t limit);
 enum_func_status xmysqlnd_crud_collection_remove__set_skip(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * obj, const size_t offset);
-enum_func_status xmysqlnd_crud_collection_remove__bind_value(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * obj, const MYSQLND_CSTRING name, zval * value);
+enum_func_status xmysqlnd_crud_collection_remove__bind_value(
+	XMYSQLND_CRUD_COLLECTION_OP__REMOVE* obj,
+	const util::string& name,
+	zval* value);
 enum_func_status xmysqlnd_crud_collection_remove__add_sort(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * obj, const MYSQLND_CSTRING sort);
 enum_func_status xmysqlnd_crud_collection_remove__finalize_bind(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * obj);
-struct st_xmysqlnd_pb_message_shell xmysqlnd_crud_collection_remove__get_protobuf_message(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * obj);
+st_xmysqlnd_pb_message_shell xmysqlnd_crud_collection_remove__get_protobuf_message(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * obj);
 zend_bool xmysqlnd_crud_collection_remove__is_initialized(XMYSQLND_CRUD_COLLECTION_OP__REMOVE * obj);
 
 
+struct Modify_value
+{
+	const util::string_view& path;
+	util::zvalue value;
+	bool is_expression;
+	bool is_document;
+	bool validate_array;
+};
+
 typedef struct st_xmysqlnd_crud_collection_op__modify XMYSQLND_CRUD_COLLECTION_OP__MODIFY;
 XMYSQLND_CRUD_COLLECTION_OP__MODIFY * xmysqlnd_crud_collection_modify__create(const MYSQLND_CSTRING schema, const MYSQLND_CSTRING collection);
 void xmysqlnd_crud_collection_modify__destroy(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj);
-enum_func_status xmysqlnd_crud_collection_modify__set_criteria(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj, const std::string& criteria);
-enum_func_status xmysqlnd_crud_collection_modify__set_limit(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj, const size_t limit);
-enum_func_status xmysqlnd_crud_collection_modify__set_skip(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj, const size_t offset);
-enum_func_status xmysqlnd_crud_collection_modify__bind_value(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj, const MYSQLND_CSTRING name, zval * value);
-enum_func_status xmysqlnd_crud_collection_modify__add_sort(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj, const MYSQLND_CSTRING sort);
+bool xmysqlnd_crud_collection_modify__set_criteria(XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj, const std::string& criteria);
+bool xmysqlnd_crud_collection_modify__set_limit(XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj, const size_t limit);
+bool xmysqlnd_crud_collection_modify__set_skip(XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj, const size_t offset);
+bool xmysqlnd_crud_collection_modify__bind_value(
+	XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj,
+	const util::string& name,
+	zval* value);
+bool xmysqlnd_crud_collection_modify__add_sort(XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj, const MYSQLND_CSTRING sort);
 
-enum_func_status xmysqlnd_crud_collection_modify__unset(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj, const MYSQLND_CSTRING path);
-enum_func_status xmysqlnd_crud_collection_modify__set(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj,
-													  const MYSQLND_CSTRING path,
-													  const zval * const value,
-													  const zend_bool is_expression,
-													  const zend_bool is_document);
-enum_func_status xmysqlnd_crud_collection_modify__replace(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj,
-														  const MYSQLND_CSTRING path,
-														  const zval * const value,
-														  const zend_bool is_expression,
-														  const zend_bool is_document);
-enum_func_status xmysqlnd_crud_collection_modify__merge(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj,
-														const MYSQLND_CSTRING path,
-														const zval * const value);
-enum_func_status xmysqlnd_crud_collection_modify__patch(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj,
-                                                        const MYSQLND_CSTRING path,
-                                                        const zval * const patch);
-enum_func_status xmysqlnd_crud_collection_modify__array_insert(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj,
-															   const MYSQLND_CSTRING path,
-															   const zval * const value);
-enum_func_status xmysqlnd_crud_collection_modify__array_append(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj,
-															   const MYSQLND_CSTRING path,
-															   const zval * const value);
-enum_func_status xmysqlnd_crud_collection_modify__array_delete(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj,
-															   const MYSQLND_CSTRING path);
-enum_func_status xmysqlnd_crud_collection_modify__finalize_bind(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj);
-struct st_xmysqlnd_pb_message_shell xmysqlnd_crud_collection_modify__get_protobuf_message(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj);
-zend_bool xmysqlnd_crud_collection_modify__is_initialized(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj);
+bool xmysqlnd_crud_collection_modify__unset(
+	XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj,
+	const util::string_view& path);
+bool xmysqlnd_crud_collection_modify__set(
+	XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj,
+	const Modify_value& modify_value);
+bool xmysqlnd_crud_collection_modify__replace(
+	XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj,
+	const Modify_value& modify_value);
+bool xmysqlnd_crud_collection_modify__merge(
+	XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj,
+	const Modify_value& modify_value);
+bool xmysqlnd_crud_collection_modify__patch(
+	XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj,
+	const Modify_value& modify_value);
+bool xmysqlnd_crud_collection_modify__array_insert(
+	XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj,
+	const Modify_value& modify_value);
+bool xmysqlnd_crud_collection_modify__array_append(
+	XMYSQLND_CRUD_COLLECTION_OP__MODIFY* obj,
+	const Modify_value& modify_value);
+bool xmysqlnd_crud_collection_modify__finalize_bind(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj);
+st_xmysqlnd_pb_message_shell xmysqlnd_crud_collection_modify__get_protobuf_message(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj);
+bool xmysqlnd_crud_collection_modify__is_initialized(XMYSQLND_CRUD_COLLECTION_OP__MODIFY * obj);
 
 
 typedef struct st_xmysqlnd_crud_collection_op__find XMYSQLND_CRUD_COLLECTION_OP__FIND;
@@ -99,7 +114,10 @@ void xmysqlnd_crud_collection_find__destroy(XMYSQLND_CRUD_COLLECTION_OP__FIND *
 enum_func_status xmysqlnd_crud_collection_find__set_criteria(XMYSQLND_CRUD_COLLECTION_OP__FIND * obj, const MYSQLND_CSTRING criteria);
 enum_func_status xmysqlnd_crud_collection_find__set_limit(XMYSQLND_CRUD_COLLECTION_OP__FIND * obj, const size_t limit);
 enum_func_status xmysqlnd_crud_collection_find__set_offset(XMYSQLND_CRUD_COLLECTION_OP__FIND * obj, const size_t offset);
-enum_func_status xmysqlnd_crud_collection_find__bind_value(XMYSQLND_CRUD_COLLECTION_OP__FIND * obj, const MYSQLND_CSTRING name, zval * value);
+enum_func_status xmysqlnd_crud_collection_find__bind_value(
+	XMYSQLND_CRUD_COLLECTION_OP__FIND* obj,
+	const util::string& name,
+	zval* value);
 enum_func_status xmysqlnd_crud_collection_find__add_sort(XMYSQLND_CRUD_COLLECTION_OP__FIND * obj, const MYSQLND_CSTRING sort);
 enum_func_status xmysqlnd_crud_collection_find__add_grouping(XMYSQLND_CRUD_COLLECTION_OP__FIND * obj, const MYSQLND_CSTRING search_field);
 enum_func_status xmysqlnd_crud_collection_find__set_having(XMYSQLND_CRUD_COLLECTION_OP__FIND * obj, const MYSQLND_CSTRING criteria);
@@ -126,13 +144,40 @@ enum_func_status xmysqlnd_stmt_execute__bind_one_param(XMYSQLND_STMT_OP__EXECUTE
 enum_func_status xmysqlnd_stmt_execute__bind_value(XMYSQLND_STMT_OP__EXECUTE* obj, zval * value);
 enum_func_status xmysqlnd_stmt_execute__finalize_bind(XMYSQLND_STMT_OP__EXECUTE* obj);
 
-struct st_xmysqlnd_pb_message_shell xmysqlnd_stmt_execute__get_protobuf_message(XMYSQLND_STMT_OP__EXECUTE* obj);
+st_xmysqlnd_pb_message_shell xmysqlnd_stmt_execute__get_protobuf_message(XMYSQLND_STMT_OP__EXECUTE* obj);
+
+class Bindings
+{
+public:
+	Bindings();
+	~Bindings();
+
+	using Bound_variable = std::pair<util::string, Mysqlx::Datatypes::Scalar*>;
+	using Bound_variables = util::vector<Bound_variable>;
+	using Bound_values = std::vector<Mysqlx::Datatypes::Scalar*>;
+
+public:
+	bool empty() const;
+	std::size_t size() const;
+	void add_placeholder(const util::string& placeholder);
+	void add_placeholders(const util::std_strings& placeholders);
+	util::std_strings get_placeholders() const;
+	bool bind(const util::string& placeholder, zval* value);
+	bool finalize(google::protobuf::RepeatedPtrField< ::Mysqlx::Datatypes::Scalar >* mutable_args);
+	Bound_values get_bound_values() const;
+
+private:
+	using Bound_variables_it = Bound_variables::iterator;
+	Bound_variables_it find_variable(const util::string& var_name);
+
+private:
+	Bound_variables bound_variables;
+};
 
 struct st_xmysqlnd_crud_collection_op__find
 {
 	Mysqlx::Crud::Find message;
-	std::vector<std::string> placeholders;
-	std::vector<Mysqlx::Datatypes::Scalar*> bound_values;
+	Bindings bindings;
 	uint32_t ps_message_id;
 	st_xmysqlnd_crud_collection_op__find(const MYSQLND_CSTRING & schema,
 										 const MYSQLND_CSTRING & object_name) :
@@ -175,8 +220,7 @@ struct st_xmysqlnd_crud_collection_op__add
 struct st_xmysqlnd_crud_collection_op__modify
 {
 	Mysqlx::Crud::Update message;
-	std::vector<std::string> placeholders;
-	std::vector<Mysqlx::Datatypes::Scalar*> bound_values;
+	Bindings bindings;
 	uint32_t ps_message_id;
 
 	st_xmysqlnd_crud_collection_op__modify(const MYSQLND_CSTRING & schema,
@@ -194,9 +238,7 @@ struct st_xmysqlnd_crud_collection_op__modify
 struct st_xmysqlnd_crud_collection_op__remove
 {
 	Mysqlx::Crud::Delete message;
-
-	std::vector<std::string> placeholders;
-	std::vector<Mysqlx::Datatypes::Scalar*> bound_values;
+	Bindings bindings;
 	uint32_t ps_message_id;
 
 	st_xmysqlnd_crud_collection_op__remove(const MYSQLND_CSTRING & schema,
@@ -246,18 +288,8 @@ struct st_xmysqlnd_stmt_op__execute
     }
 };
 
-
 } // namespace drv
 
 } // namespace mysqlx
 
 #endif /* XMYSQLND_CRUD_COLLECTION_COMMANDS_H */
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
