@@ -29,7 +29,6 @@ namespace mysqlx {
 
 namespace drv {
 
-/* {{{ xmysqlnd_rowset_fwd::init */
 static enum_func_status
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, init)(XMYSQLND_ROWSET_FWD * const result,
 										   const MYSQLND_CLASS_METHODS_TYPE(xmysqlnd_object_factory) * const /*factory*/,
@@ -43,10 +42,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, init)(XMYSQLND_ROWSET_FWD * const result,
 	result->prefetch_rows = prefetch_rows;
 	DBG_RETURN(result->stmt? PASS:FAIL);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::next */
 static enum_func_status
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, next)(XMYSQLND_ROWSET_FWD * const result,
 										   MYSQLND_STATS * const stats,
@@ -54,7 +50,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, next)(XMYSQLND_ROWSET_FWD * const result,
 {
 	const zend_bool no_more_on_the_line = !result->stmt->get_msg_stmt_exec().reader_ctx.has_more_rows_in_set;
 	DBG_ENTER("xmysqlnd_rowset_fwd::next");
-	DBG_INF_FMT("row_cursor=" MYSQLND_LLU_SPEC "  row_count=" MYSQLND_LLU_SPEC, result->row_cursor, result->row_count);
+	DBG_INF_FMT("row_cursor=" MYSQLX_LLU_SPEC "  row_count=" MYSQLX_LLU_SPEC, result->row_cursor, result->row_count);
 
 	if ((result->row_count - result->row_cursor) == 1 && !no_more_on_the_line) {
 		DBG_INF_FMT("We have to prefetch %u row(s)", result->prefetch_rows);
@@ -73,10 +69,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, next)(XMYSQLND_ROWSET_FWD * const result,
 	}
 	DBG_RETURN(PASS);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::fetch_current */
 static enum_func_status
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, fetch_current)(XMYSQLND_ROWSET_FWD * const result, zval * row, MYSQLND_STATS * const stats, MYSQLND_ERROR_INFO * const error_info)
 {
@@ -87,10 +80,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, fetch_current)(XMYSQLND_ROWSET_FWD * const
 	DBG_INF_FMT("%s", PASS == ret? "PASS":"FAIL");
 	DBG_RETURN(ret);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::fetch_one */
 static enum_func_status
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, fetch_one)(XMYSQLND_ROWSET_FWD * const result,
 												const size_t row_cursor,
@@ -101,7 +91,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, fetch_one)(XMYSQLND_ROWSET_FWD * const resu
 	const unsigned int field_count = result->meta->m->get_field_count(result->meta);
 	const size_t row_count = result->row_count;
 	DBG_ENTER("xmysqlnd_rowset_fwd::fetch_one");
-	DBG_INF_FMT("row_cursor=" MYSQLND_LLU_SPEC "  row_count=" MYSQLND_LLU_SPEC, result->row_cursor, result->row_count);
+	DBG_INF_FMT("row_cursor=" MYSQLX_LLU_SPEC "  row_count=" MYSQLX_LLU_SPEC, result->row_cursor, result->row_count);
 	if (row_cursor >= row_count || !result->rows[row_cursor]) {
 		DBG_RETURN(FAIL);
 	}
@@ -124,10 +114,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, fetch_one)(XMYSQLND_ROWSET_FWD * const resu
 	++result->total_fetched;
 	DBG_RETURN(PASS);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::fetch_all */
 static enum_func_status
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, fetch_all)(XMYSQLND_ROWSET_FWD * const result, zval * set, MYSQLND_STATS * const stats, MYSQLND_ERROR_INFO * const error_info)
 {
@@ -153,13 +140,10 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, fetch_all)(XMYSQLND_ROWSET_FWD * const resu
 		/* Remove what we have, as we don't need it anymore */
 		result->m.free_rows_contents(result, stats, error_info);
 	}
-	DBG_INF_FMT("total_row_count=" MYSQLND_LLU_SPEC, result->total_row_count);
+	DBG_INF_FMT("total_row_count=" MYSQLX_LLU_SPEC, result->total_row_count);
 	DBG_RETURN(PASS);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::rewind */
 static enum_func_status
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, rewind)(XMYSQLND_ROWSET_FWD * const result)
 {
@@ -171,10 +155,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, rewind)(XMYSQLND_ROWSET_FWD * const result)
 		DBG_RETURN(FAIL);
 	}
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::eof */
 static zend_bool
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, eof)(const XMYSQLND_ROWSET_FWD * const result)
 {
@@ -186,10 +167,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, eof)(const XMYSQLND_ROWSET_FWD * const resu
 	DBG_INF_FMT("eof=%s", no_more_on_the_line && no_more_prefetched ? "TRUE":"FALSE");
 	DBG_RETURN(no_more_on_the_line && no_more_prefetched ? TRUE:FALSE);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::create_row */
 static zval *
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, create_row)(XMYSQLND_ROWSET_FWD * const result,
 												 const XMYSQLND_STMT_RESULT_META * const meta,
@@ -202,10 +180,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, create_row)(XMYSQLND_ROWSET_FWD * const res
 	DBG_INF_FMT("row=%p", row);
 	DBG_RETURN(row);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::destroy_row */
 static void
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, destroy_row)(XMYSQLND_ROWSET_FWD * const result,
 												  zval * row,
@@ -219,10 +194,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, destroy_row)(XMYSQLND_ROWSET_FWD * const re
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::add_row */
 static enum_func_status
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, add_row)(XMYSQLND_ROWSET_FWD * const result, zval * row, MYSQLND_STATS * const /*stats*/, MYSQLND_ERROR_INFO * const /*error_info*/)
 {
@@ -244,10 +216,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, add_row)(XMYSQLND_ROWSET_FWD * const result
 																	   static_cast<unsigned int>(result->total_row_count));
 	DBG_RETURN(PASS);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::get_row_count */
 static size_t
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, get_row_count)(const XMYSQLND_ROWSET_FWD * const result)
 {
@@ -255,10 +224,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, get_row_count)(const XMYSQLND_ROWSET_FWD *
 	DBG_INF_FMT("count=%u", static_cast<unsigned int>(result->row_count));
 	DBG_RETURN(result->row_count);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::attach_meta */
 static enum_func_status
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, attach_meta)(XMYSQLND_ROWSET_FWD * const result, XMYSQLND_STMT_RESULT_META * const meta, MYSQLND_STATS * const stats, MYSQLND_ERROR_INFO * const error_info)
 {
@@ -271,10 +237,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, attach_meta)(XMYSQLND_ROWSET_FWD * const re
 	}
 	DBG_RETURN(PASS);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::free_rows_contents */
 static void
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, free_rows_contents)(XMYSQLND_ROWSET_FWD * const result, MYSQLND_STATS * stats, MYSQLND_ERROR_INFO * error_info)
 {
@@ -298,10 +261,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, free_rows_contents)(XMYSQLND_ROWSET_FWD * c
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::free_rows */
 static void
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, free_rows)(XMYSQLND_ROWSET_FWD * const result, MYSQLND_STATS * stats, MYSQLND_ERROR_INFO * error_info)
 {
@@ -318,10 +278,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, free_rows)(XMYSQLND_ROWSET_FWD * const resu
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::free_contents */
 static void
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, free_contents)(XMYSQLND_ROWSET_FWD * const result, MYSQLND_STATS * stats, MYSQLND_ERROR_INFO * error_info)
 {
@@ -334,10 +291,7 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, free_contents)(XMYSQLND_ROWSET_FWD * const
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd::dtor */
 static void
 XMYSQLND_METHOD(xmysqlnd_rowset_fwd, dtor)(XMYSQLND_ROWSET_FWD * const result, MYSQLND_STATS * stats, MYSQLND_ERROR_INFO * error_info)
 {
@@ -352,8 +306,6 @@ XMYSQLND_METHOD(xmysqlnd_rowset_fwd, dtor)(XMYSQLND_ROWSET_FWD * const result, M
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
-
 
 static
 MYSQLND_CLASS_METHODS_START(xmysqlnd_rowset_fwd)
@@ -381,7 +333,6 @@ MYSQLND_CLASS_METHODS_END;
 
 PHP_MYSQL_XDEVAPI_API MYSQLND_CLASS_METHODS_INSTANCE_DEFINE(xmysqlnd_rowset_fwd);
 
-/* {{{ xmysqlnd_rowset_fwd_create */
 PHP_MYSQL_XDEVAPI_API XMYSQLND_ROWSET_FWD *
 xmysqlnd_rowset_fwd_create(const size_t prefetch_rows,
 						   xmysqlnd_stmt * stmt,
@@ -395,10 +346,7 @@ xmysqlnd_rowset_fwd_create(const size_t prefetch_rows,
 	result = object_factory->get_rowset_fwd(object_factory, prefetch_rows, stmt, persistent, stats, error_info);
 	DBG_RETURN(result);
 }
-/* }}} */
 
-
-/* {{{ xmysqlnd_rowset_fwd_free */
 PHP_MYSQL_XDEVAPI_API void
 xmysqlnd_rowset_fwd_free(XMYSQLND_ROWSET_FWD * const result, MYSQLND_STATS * stats, MYSQLND_ERROR_INFO * error_info)
 {
@@ -409,17 +357,7 @@ xmysqlnd_rowset_fwd_free(XMYSQLND_ROWSET_FWD * const result, MYSQLND_STATS * sta
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
 } // namespace drv
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
