@@ -52,7 +52,6 @@ void zval2object(zval* zv, Mysqlx::Datatypes::Any& any)
 
 } // anonymous namespace
 
-/* {{{ zval2any */
 PHP_MYSQL_XDEVAPI_API enum_func_status
 zval2any(const zval * const zv, Mysqlx::Datatypes::Any & any)
 {
@@ -123,10 +122,7 @@ zval2any(const zval * const zv, Mysqlx::Datatypes::Any & any)
 	}
 	DBG_RETURN(PASS);
 }
-/* }}} */
 
-
-/* {{{ scalar2zval */
 PHP_MYSQL_XDEVAPI_API enum_func_status
 scalar2zval(const Mysqlx::Datatypes::Scalar & scalar, zval * zv)
 {
@@ -184,10 +180,7 @@ scalar2zval(const Mysqlx::Datatypes::Scalar & scalar, zval * zv)
 	}
 	DBG_RETURN(PASS);
 }
-/* }}} */
 
-
-/* {{{ any2zval */
 PHP_MYSQL_XDEVAPI_API enum_func_status
 any2zval(const Mysqlx::Datatypes::Any & any, zval * zv)
 {
@@ -290,10 +283,7 @@ any2zval(const Mysqlx::Datatypes::Any & any, zval * zv)
 	}
 	DBG_RETURN(PASS);
 }
-/* }}} */
 
-
-/* {{{ scalar2uint */
 PHP_MYSQL_XDEVAPI_API uint64_t
 scalar2uint(const Mysqlx::Datatypes::Scalar & scalar)
 {
@@ -330,10 +320,7 @@ scalar2uint(const Mysqlx::Datatypes::Scalar & scalar)
 	}
 	DBG_RETURN(ret);
 }
-/* }}} */
 
-
-/* {{{ scalar2uint */
 PHP_MYSQL_XDEVAPI_API int64_t
 scalar2sint(const Mysqlx::Datatypes::Scalar & scalar)
 {
@@ -370,10 +357,7 @@ scalar2sint(const Mysqlx::Datatypes::Scalar & scalar)
 	}
 	DBG_RETURN(ret);
 }
-/* }}} */
 
-
-/* {{{ scalar2string */
 PHP_MYSQL_XDEVAPI_API MYSQLND_STRING
 scalar2string(const Mysqlx::Datatypes::Scalar & scalar)
 {
@@ -382,10 +366,10 @@ scalar2string(const Mysqlx::Datatypes::Scalar & scalar)
 	DBG_INF_FMT("subtype=%s", Scalar::Type_Name(scalar.type()).c_str());
 	switch (scalar.type()) {
 		case Scalar_Type_V_SINT:
-			ret.l = mnd_sprintf(&ret.s, 0, MYSQLND_LLU_SPEC, scalar.v_signed_int());
+			ret.l = mnd_sprintf(&ret.s, 0, MYSQLX_LLU_SPEC, scalar.v_signed_int());
 			break;
 		case Scalar_Type_V_UINT:
-			ret.l = mnd_sprintf(&ret.s, 0, MYSQLND_LLU_SPEC, scalar.v_unsigned_int());
+			ret.l = mnd_sprintf(&ret.s, 0, MYSQLX_LLU_SPEC, scalar.v_unsigned_int());
 			break;
 		case Scalar_Type_V_NULL:
 			break;
@@ -415,10 +399,7 @@ scalar2string(const Mysqlx::Datatypes::Scalar & scalar)
 	}
 	DBG_RETURN(ret);
 }
-/* }}} */
 
-
-/* {{{ scalar2log */
 PHP_MYSQL_XDEVAPI_API void
 scalar2log(const Mysqlx::Datatypes::Scalar & scalar)
 {
@@ -434,7 +415,7 @@ scalar2log(const Mysqlx::Datatypes::Scalar & scalar)
 			} else
 #endif
 			{
-				DBG_INF_FMT("value=" MYSQLND_LLU_SPEC, scalar.v_signed_int());
+				DBG_INF_FMT("value=" MYSQLX_LLU_SPEC, scalar.v_signed_int());
 			}
 			break;
 		case Scalar_Type_V_UINT:
@@ -447,7 +428,7 @@ scalar2log(const Mysqlx::Datatypes::Scalar & scalar)
 				snprintf(tmp, sizeof(tmp), "%s", util::to_string(scalar.v_unsigned_int()).c_str());
 				DBG_INF_FMT("value=%s", tmp);
 			} else {
-				DBG_INF_FMT("value=" MYSQLND_LLU_SPEC, scalar.v_unsigned_int());
+				DBG_INF_FMT("value=" MYSQLX_LLU_SPEC, scalar.v_unsigned_int());
 			}
 			break;
 		case Scalar_Type_V_NULL:
@@ -472,10 +453,7 @@ scalar2log(const Mysqlx::Datatypes::Scalar & scalar)
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ any2log */
 PHP_MYSQL_XDEVAPI_API void
 any2log(const Mysqlx::Datatypes::Any & any)
 {
@@ -507,10 +485,7 @@ any2log(const Mysqlx::Datatypes::Any & any)
 	}
 	DBG_VOID_RETURN;
 }
-/* }}} */
 
-
-/* {{{ repeated2log */
 PHP_MYSQL_XDEVAPI_API void repeated2log(
 	const google::protobuf::RepeatedPtrField< Mysqlx::Datatypes::Scalar >& repeated)
 {
@@ -518,18 +493,7 @@ PHP_MYSQL_XDEVAPI_API void repeated2log(
 		scalar2log(scalar);
 	}
 }
-/* }}} */
-
 
 } // namespace drv
 
 } // namespace mysqlx
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: noet sw=4 ts=4 fdm=marker
- * vim<600: noet sw=4 ts=4
- */
